/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */



#ifndef SBK_QTCORE_PYTHON_H
#define SBK_QTCORE_PYTHON_H

//workaround to access protected functions
#define protected public

#include <Python.h>
#include <conversions.h>
#include <sbkenum.h>
#include <basewrapper.h>
#include <bindingmanager.h>
#include <memory>

#include <pysidesignal.h>
// Binded library includes
#include <qstatemachine.h>
#include <qprocess.h>
#include <qtextdocument.h>
#include <qeventtransition.h>
#include <qelapsedtimer.h>
#include <qfile.h>
#include <qfilesystemwatcher.h>
#include <qrunnable.h>
#include <qbasictimer.h>
#include <qfinalstate.h>
#include <qlibraryinfo.h>
#include <qabstractitemmodel.h>
#include <qsignalmapper.h>
#include <qthreadpool.h>
#include <qsettings.h>
#include <qobjectdefs.h>
#include <qabstracteventdispatcher.h>
#include <qtemporaryfile.h>
#include <qresource.h>
#include <qreadwritelock.h>
#include <qtconcurrentexception.h>
#include <qdiriterator.h>
#include <qmetaobject.h>
#include <qsequentialanimationgroup.h>
#include <qwaitcondition.h>
#include <qiodevice.h>
#include <qsystemsemaphore.h>
#include <qpoint.h>
#include <qsocketnotifier.h>
#include <QTextCodec>
#include <qthread.h>
#include <qstate.h>
#include <qabstractstate.h>
#include <qparallelanimationgroup.h>
#include <qmargins.h>
#include <qfactoryinterface.h>
#include <qcoreevent.h>
#include <qbytearraymatcher.h>
#include <qmutex.h>
#include <qsemaphore.h>
#include <qpluginloader.h>
#include <qtranslator.h>
#include <qfileinfo.h>
#include <qtimeline.h>
#include <qabstractfileengine.h>
#include <qpropertyanimation.h>
#include <quuid.h>
#include <qdir.h>
#include <qhistorystate.h>
#include <qsignaltransition.h>
#include <qcryptographichash.h>
#include <qrect.h>
#include <qdatastream.h>
#include <qbitarray.h>
#include <qeasingcurve.h>
#include <qtextstream.h>
#include <qanimationgroup.h>
#include <qglobal.h>
#include <qfsfileengine.h>
#include <qabstractanimation.h>
#include <qmimedata.h>
#include <qbytearray.h>
#include <qvariantanimation.h>
#include <qtconcurrentreducekernel.h>
#include <qtextboundaryfinder.h>
#include <qnamespace.h>
#include <qregexp.h>
#include <qbuffer.h>
#include <qabstracttransition.h>
#include <qtextcodec.h>
#include <qdatetime.h>
#include <qpauseanimation.h>
#include <qxmlstream.h>
#include <qeventloop.h>
#include <qurl.h>
#include <qlocale.h>
#include <qcoreapplication.h>
#include <qobject.h>
#include <qsize.h>
#include <qline.h>
#include <qtimer.h>
// Conversion Includes - Primitive Types
#include <QString>
#include <signalmanager.h>
#include <typeresolver.h>
#include <QtConcurrentFilter>
#include <QTextDocument>

// Conversion Includes - Container Types
#include <QList>
#include <QMap>
#include <QStack>
#include <QMultiMap>
#include <QVector>
#include <QPair>
#include <pysideconversions.h>
#include <QSet>
#include <qqueue.h>
#include <QStringList>
#include <qlinkedlist.h>

// Type indices
#define SBK_QTCONCURRENT_IDX                                         0
#define SBK_QTCONCURRENT_REDUCEOPTION_IDX                            1
#define SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION__IDX                    2
#define SBK_QT_IDX                                                   3
#define SBK_QT_SHORTCUTCONTEXT_IDX                                   4
#define SBK_QT_CHECKSTATE_IDX                                        5
#define SBK_QT_FOCUSPOLICY_IDX                                       6
#define SBK_QT_GESTURETYPE_IDX                                       7
#define SBK_QT_DROPACTION_IDX                                        8
#define SBK_QFLAGS_QT_DROPACTION__IDX                                9
#define SBK_QT_WINDOWTYPE_IDX                                        10
#define SBK_QFLAGS_QT_WINDOWTYPE__IDX                                11
#define SBK_QT_DATEFORMAT_IDX                                        12
#define SBK_QT_TEXTFORMAT_IDX                                        13
#define SBK_QT_PENJOINSTYLE_IDX                                      14
#define SBK_QT_GESTUREFLAG_IDX                                       15
#define SBK_QFLAGS_QT_GESTUREFLAG__IDX                               16
#define SBK_QT_CASESENSITIVITY_IDX                                   17
#define SBK_QT_EVENTPRIORITY_IDX                                     18
#define SBK_QT_IMAGECONVERSIONFLAG_IDX                               19
#define SBK_QFLAGS_QT_IMAGECONVERSIONFLAG__IDX                       20
#define SBK_QT_GESTURESTATE_IDX                                      21
#define SBK_QT_BGMODE_IDX                                            22
#define SBK_QT_CONNECTIONTYPE_IDX                                    23
#define SBK_QT_TOOLBARAREA_IDX                                       24
#define SBK_QFLAGS_QT_TOOLBARAREA__IDX                               25
#define SBK_QT_COORDINATESYSTEM_IDX                                  26
#define SBK_QT_SIZEMODE_IDX                                          27
#define SBK_QT_FOCUSREASON_IDX                                       28
#define SBK_QT_MODIFIER_IDX                                          29
#define SBK_QT_TILERULE_IDX                                          30
#define SBK_QT_WHITESPACEMODE_IDX                                    31
#define SBK_QT_ASPECTRATIOMODE_IDX                                   32
#define SBK_QT_SIZEHINT_IDX                                          33
#define SBK_QT_ALIGNMENTFLAG_IDX                                     34
#define SBK_QFLAGS_QT_ALIGNMENTFLAG__IDX                             35
#define SBK_QT_CONTEXTMENUPOLICY_IDX                                 36
#define SBK_QT_DOCKWIDGETAREA_IDX                                    37
#define SBK_QFLAGS_QT_DOCKWIDGETAREA__IDX                            38
#define SBK_QT_UIEFFECT_IDX                                          39
#define SBK_QT_ANCHORPOINT_IDX                                       40
#define SBK_QT_GLOBALCOLOR_IDX                                       41
#define SBK_QT_KEYBOARDMODIFIER_IDX                                  42
#define SBK_QFLAGS_QT_KEYBOARDMODIFIER__IDX                          43
#define SBK_QT_NAVIGATIONMODE_IDX                                    44
#define SBK_QT_ITEMDATAROLE_IDX                                      45
#define SBK_QT_SCROLLBARPOLICY_IDX                                   46
#define SBK_QT_INPUTMETHODHINT_IDX                                   47
#define SBK_QFLAGS_QT_INPUTMETHODHINT__IDX                           48
#define SBK_QT_ANCHORATTRIBUTE_IDX                                   49
#define SBK_QT_WINDOWMODALITY_IDX                                    50
#define SBK_QT_SORTORDER_IDX                                         51
#define SBK_QT_PENSTYLE_IDX                                          52
#define SBK_QT_ITEMFLAG_IDX                                          53
#define SBK_QFLAGS_QT_ITEMFLAG__IDX                                  54
#define SBK_QT_AXIS_IDX                                              55
#define SBK_QT_TRANSFORMATIONMODE_IDX                                56
#define SBK_QT_WINDOWFRAMESECTION_IDX                                57
#define SBK_QT_HITTESTACCURACY_IDX                                   58
#define SBK_QT_CURSORSHAPE_IDX                                       59
#define SBK_QT_ITEMSELECTIONMODE_IDX                                 60
#define SBK_QT_ORIENTATION_IDX                                       61
#define SBK_QFLAGS_QT_ORIENTATION__IDX                               62
#define SBK_QT_INPUTMETHODQUERY_IDX                                  63
#define SBK_QT_TIMESPEC_IDX                                          64
#define SBK_QT_ARROWTYPE_IDX                                         65
#define SBK_QT_FILLRULE_IDX                                          66
#define SBK_QT_MASKMODE_IDX                                          67
#define SBK_QT_WINDOWSTATE_IDX                                       68
#define SBK_QFLAGS_QT_WINDOWSTATE__IDX                               69
#define SBK_QT_TOOLBARAREASIZES_IDX                                  70
#define SBK_QT_CORNER_IDX                                            71
#define SBK_QT_DAYOFWEEK_IDX                                         72
#define SBK_QT_CLIPOPERATION_IDX                                     73
#define SBK_QT_LAYOUTDIRECTION_IDX                                   74
#define SBK_QT_TOOLBUTTONSTYLE_IDX                                   75
#define SBK_QT_DOCKWIDGETAREASIZES_IDX                               76
#define SBK_QT_KEY_IDX                                               77
#define SBK_QT_APPLICATIONATTRIBUTE_IDX                              78
#define SBK_QT_TEXTFLAG_IDX                                          79
#define SBK_QT_BRUSHSTYLE_IDX                                        80
#define SBK_QT_WIDGETATTRIBUTE_IDX                                   81
#define SBK_QT_TOUCHPOINTSTATE_IDX                                   82
#define SBK_QT_TEXTINTERACTIONFLAG_IDX                               83
#define SBK_QFLAGS_QT_TEXTINTERACTIONFLAG__IDX                       84
#define SBK_QT_MOUSEBUTTON_IDX                                       85
#define SBK_QFLAGS_QT_MOUSEBUTTON__IDX                               86
#define SBK_QT_MATCHFLAG_IDX                                         87
#define SBK_QFLAGS_QT_MATCHFLAG__IDX                                 88
#define SBK_QT_PENCAPSTYLE_IDX                                       89
#define SBK_QT_TEXTELIDEMODE_IDX                                     90
#define SBK_QTEXTBOUNDARYFINDER_IDX                                  91
#define SBK_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX                   92
#define SBK_QFLAGS_QTEXTBOUNDARYFINDER_BOUNDARYREASON__IDX           93
#define SBK_QTEXTBOUNDARYFINDER_BOUNDARYTYPE_IDX                     94
#define SBK_QRECTF_IDX                                               95
#define SBK_QRECT_IDX                                                96
#define SBK_QSIZEF_IDX                                               97
#define SBK_QSIZE_IDX                                                98
#define SBK_QMARGINS_IDX                                             99
#define SBK_QLINEF_IDX                                               100
#define SBK_QLINEF_INTERSECTTYPE_IDX                                 101
#define SBK_QLINE_IDX                                                102
#define SBK_QPOINTF_IDX                                              103
#define SBK_QPOINT_IDX                                               104
#define SBK_QELAPSEDTIMER_IDX                                        105
#define SBK_QELAPSEDTIMER_CLOCKTYPE_IDX                              106
#define SBK_QCRYPTOGRAPHICHASH_IDX                                   107
#define SBK_QCRYPTOGRAPHICHASH_ALGORITHM_IDX                         108
#define SBK_QBYTEARRAYMATCHER_IDX                                    109
#define SBK_QBITARRAY_IDX                                            110
#define SBK_QPROCESSENVIRONMENT_IDX                                  111
#define SBK_QABSTRACTFILEENGINEITERATOR_IDX                          112
#define SBK_QABSTRACTFILEENGINEHANDLER_IDX                           113
#define SBK_QABSTRACTFILEENGINE_IDX                                  114
#define SBK_QABSTRACTFILEENGINE_FILENAME_IDX                         115
#define SBK_QABSTRACTFILEENGINE_FILETIME_IDX                         116
#define SBK_QABSTRACTFILEENGINE_FILEOWNER_IDX                        117
#define SBK_QABSTRACTFILEENGINE_EXTENSION_IDX                        118
#define SBK_QABSTRACTFILEENGINE_FILEFLAG_IDX                         119
#define SBK_QFLAGS_QABSTRACTFILEENGINE_FILEFLAG__IDX                 120
#define SBK_QFSFILEENGINE_IDX                                        121
#define SBK_QDIR_IDX                                                 122
#define SBK_QDIR_FILTER_IDX                                          123
#define SBK_QFLAGS_QDIR_FILTER__IDX                                  124
#define SBK_QDIR_SORTFLAG_IDX                                        125
#define SBK_QFLAGS_QDIR_SORTFLAG__IDX                                126
#define SBK_QDIRITERATOR_IDX                                         127
#define SBK_QDIRITERATOR_ITERATORFLAG_IDX                            128
#define SBK_QFLAGS_QDIRITERATOR_ITERATORFLAG__IDX                    129
#define SBK_QFILEINFO_IDX                                            130
#define SBK_QWRITELOCKER_IDX                                         131
#define SBK_QREADLOCKER_IDX                                          132
#define SBK_QREADWRITELOCK_IDX                                       133
#define SBK_QREADWRITELOCK_RECURSIONMODE_IDX                         134
#define SBK_QSEMAPHORE_IDX                                           135
#define SBK_QWAITCONDITION_IDX                                       136
#define SBK_QTEXTSTREAMMANIPULATOR_IDX                               137
#define SBK_QLOCALE_IDX                                              138
#define SBK_QLOCALE_MEASUREMENTSYSTEM_IDX                            139
#define SBK_QLOCALE_NUMBEROPTION_IDX                                 140
#define SBK_QFLAGS_QLOCALE_NUMBEROPTION__IDX                         141
#define SBK_QLOCALE_FORMATTYPE_IDX                                   142
#define SBK_QLOCALE_COUNTRY_IDX                                      143
#define SBK_QLOCALE_LANGUAGE_IDX                                     144
#define SBK_QRESOURCE_IDX                                            145
#define SBK_QSYSTEMLOCALE_IDX                                        146
#define SBK_QSYSTEMLOCALE_QUERYTYPE_IDX                              147
#define SBK_QMUTEXLOCKER_IDX                                         148
#define SBK_QMUTEX_IDX                                               149
#define SBK_QMUTEX_RECURSIONMODE_IDX                                 150
#define SBK_QRUNNABLE_IDX                                            151
#define SBK_QUUID_IDX                                                152
#define SBK_QUUID_VARIANT_IDX                                        153
#define SBK_QUUID_VERSION_IDX                                        154
#define SBK_QXMLSTREAMWRITER_IDX                                     155
#define SBK_QXMLSTREAMREADER_IDX                                     156
#define SBK_QXMLSTREAMREADER_ERROR_IDX                               157
#define SBK_QXMLSTREAMREADER_TOKENTYPE_IDX                           158
#define SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX            159
#define SBK_QXMLSTREAMENTITYRESOLVER_IDX                             160
#define SBK_QXMLSTREAMENTITYDECLARATION_IDX                          161
#define SBK_QXMLSTREAMNOTATIONDECLARATION_IDX                        162
#define SBK_QXMLSTREAMNAMESPACEDECLARATION_IDX                       163
#define SBK_QXMLSTREAMATTRIBUTES_IDX                                 164
#define SBK_QXMLSTREAMATTRIBUTE_IDX                                  165
#define SBK_QFACTORYINTERFACE_IDX                                    166
#define SBK_QREGEXP_IDX                                              167
#define SBK_QREGEXP_PATTERNSYNTAX_IDX                                168
#define SBK_QREGEXP_CARETMODE_IDX                                    169
#define SBK_QTEXTDECODER_IDX                                         170
#define SBK_QTEXTENCODER_IDX                                         171
#define SBK_QTEXTCODEC_IDX                                           172
#define SBK_QTEXTCODEC_CONVERSIONFLAG_IDX                            173
#define SBK_QFLAGS_QTEXTCODEC_CONVERSIONFLAG__IDX                    174
#define SBK_QTEXTCODEC_CONVERTERSTATE_IDX                            175
#define SBK_QSYSTEMSEMAPHORE_IDX                                     176
#define SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX                          177
#define SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX                178
#define SBK_QMETACLASSINFO_IDX                                       179
#define SBK_QMETAPROPERTY_IDX                                        180
#define SBK_QMETAENUM_IDX                                            181
#define SBK_QEVENT_IDX                                               182
#define SBK_QEVENT_TYPE_IDX                                          183
#define SBK_QDYNAMICPROPERTYCHANGEEVENT_IDX                          184
#define SBK_QCHILDEVENT_IDX                                          185
#define SBK_QTIMEREVENT_IDX                                          186
#define SBK_QBASICTIMER_IDX                                          187
#define SBK_QPERSISTENTMODELINDEX_IDX                                188
#define SBK_QMODELINDEX_IDX                                          189
#define SBK_QDATETIME_IDX                                            190
#define SBK_QTIME_IDX                                                191
#define SBK_QDATE_IDX                                                192
#define SBK_QDATE_MONTHNAMETYPE_IDX                                  193
#define SBK_QDATASTREAM_IDX                                          194
#define SBK_QDATASTREAM_FLOATINGPOINTPRECISION_IDX                   195
#define SBK_QDATASTREAM_VERSION_IDX                                  196
#define SBK_QDATASTREAM_STATUS_IDX                                   197
#define SBK_QEASINGCURVE_IDX                                         198
#define SBK_QEASINGCURVE_TYPE_IDX                                    199
#define SBK_QOBJECT_IDX                                              200
#define SBK_QABSTRACTTRANSITION_IDX                                  201
#define SBK_QSIGNALTRANSITION_IDX                                    202
#define SBK_QEVENTTRANSITION_IDX                                     203
#define SBK_QABSTRACTSTATE_IDX                                       204
#define SBK_QSTATE_IDX                                               205
#define SBK_QSTATE_CHILDMODE_IDX                                     206
#define SBK_QSTATEMACHINE_IDX                                        207
#define SBK_QSTATEMACHINE_ERROR_IDX                                  208
#define SBK_QSTATEMACHINE_EVENTPRIORITY_IDX                          209
#define SBK_QSTATEMACHINE_RESTOREPOLICY_IDX                          210
#define SBK_QSTATEMACHINE_WRAPPEDEVENT_IDX                           211
#define SBK_QSTATEMACHINE_SIGNALEVENT_IDX                            212
#define SBK_QHISTORYSTATE_IDX                                        213
#define SBK_QHISTORYSTATE_HISTORYTYPE_IDX                            214
#define SBK_QFINALSTATE_IDX                                          215
#define SBK_QTHREADPOOL_IDX                                          216
#define SBK_QTHREAD_IDX                                              217
#define SBK_QTHREAD_PRIORITY_IDX                                     218
#define SBK_QABSTRACTITEMMODEL_IDX                                   219
#define SBK_QABSTRACTLISTMODEL_IDX                                   220
#define SBK_QABSTRACTTABLEMODEL_IDX                                  221
#define SBK_QSETTINGS_IDX                                            222
#define SBK_QSETTINGS_FORMAT_IDX                                     223
#define SBK_QSETTINGS_STATUS_IDX                                     224
#define SBK_QSETTINGS_SCOPE_IDX                                      225
#define SBK_QABSTRACTEVENTDISPATCHER_IDX                             226
#define SBK_QPLUGINLOADER_IDX                                        227
#define SBK_QEVENTLOOP_IDX                                           228
#define SBK_QEVENTLOOP_PROCESSEVENTSFLAG_IDX                         229
#define SBK_QFLAGS_QEVENTLOOP_PROCESSEVENTSFLAG__IDX                 230
#define SBK_QCOREAPPLICATION_IDX                                     231
#define SBK_QCOREAPPLICATION_ENCODING_IDX                            232
#define SBK_QFILESYSTEMWATCHER_IDX                                   233
#define SBK_QIODEVICE_IDX                                            234
#define SBK_QIODEVICE_OPENMODEFLAG_IDX                               235
#define SBK_QFLAGS_QIODEVICE_OPENMODEFLAG__IDX                       236
#define SBK_QFILE_IDX                                                237
#define SBK_QFILE_FILEERROR_IDX                                      238
#define SBK_QFILE_MEMORYMAPFLAGS_IDX                                 239
#define SBK_QFILE_PERMISSION_IDX                                     240
#define SBK_QFLAGS_QFILE_PERMISSION__IDX                             241
#define SBK_QTEMPORARYFILE_IDX                                       242
#define SBK_QTEXTSTREAM_IDX                                          243
#define SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX                       244
#define SBK_QTEXTSTREAM_NUMBERFLAG_IDX                               245
#define SBK_QFLAGS_QTEXTSTREAM_NUMBERFLAG__IDX                       246
#define SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX                           247
#define SBK_QTEXTSTREAM_STATUS_IDX                                   248
#define SBK_QPROCESS_IDX                                             249
#define SBK_QPROCESS_PROCESSERROR_IDX                                250
#define SBK_QPROCESS_PROCESSCHANNELMODE_IDX                          251
#define SBK_QPROCESS_PROCESSCHANNEL_IDX                              252
#define SBK_QPROCESS_PROCESSSTATE_IDX                                253
#define SBK_QPROCESS_EXITSTATUS_IDX                                  254
#define SBK_QBUFFER_IDX                                              255
#define SBK_QABSTRACTANIMATION_IDX                                   256
#define SBK_QABSTRACTANIMATION_DIRECTION_IDX                         257
#define SBK_QABSTRACTANIMATION_DELETIONPOLICY_IDX                    258
#define SBK_QABSTRACTANIMATION_STATE_IDX                             259
#define SBK_QVARIANTANIMATION_IDX                                    260
#define SBK_QPROPERTYANIMATION_IDX                                   261
#define SBK_QPAUSEANIMATION_IDX                                      262
#define SBK_QANIMATIONGROUP_IDX                                      263
#define SBK_QSEQUENTIALANIMATIONGROUP_IDX                            264
#define SBK_QPARALLELANIMATIONGROUP_IDX                              265
#define SBK_QTRANSLATOR_IDX                                          266
#define SBK_QTIMER_IDX                                               267
#define SBK_QTIMELINE_IDX                                            268
#define SBK_QTIMELINE_DIRECTION_IDX                                  269
#define SBK_QTIMELINE_CURVESHAPE_IDX                                 270
#define SBK_QTIMELINE_STATE_IDX                                      271
#define SBK_QSOCKETNOTIFIER_IDX                                      272
#define SBK_QSOCKETNOTIFIER_TYPE_IDX                                 273
#define SBK_QSIGNALMAPPER_IDX                                        274
#define SBK_QMIMEDATA_IDX                                            275
#define SBK_QLIBRARYINFO_IDX                                         276
#define SBK_QLIBRARYINFO_LIBRARYLOCATION_IDX                         277
#define SBK_QBYTEARRAY_IDX                                           278
#define SBK_QURL_IDX                                                 279
#define SBK_QURL_PARSINGMODE_IDX                                     280
#define SBK_QURL_FORMATTINGOPTION_IDX                                281
#define SBK_QFLAGS_QURL_FORMATTINGOPTION__IDX                        282
#define SBK_QGENERICARGUMENT_IDX                                     283
#define SBK_QMETAMETHOD_IDX                                          284
#define SBK_QMETAMETHOD_ACCESS_IDX                                   285
#define SBK_QMETAMETHOD_METHODTYPE_IDX                               286
#define SBK_QMETAOBJECT_IDX                                          287
#define SBK_QMETAOBJECT_CALL_IDX                                     288
#define SBK_QGENERICRETURNARGUMENT_IDX                               289
#define SBK_QSYSINFO_IDX                                             290
#define SBK_QSYSINFO_ENDIAN_IDX                                      291
#define SBK_QSYSINFO_SIZES_IDX                                       292
#define SBK_QTVALIDLICENSEFOROPENVGMODULE_IDX                        293
#define SBK_QTVALIDLICENSEFORMULTIMEDIAMODULE_IDX                    294
#define SBK_QTMSGTYPE_IDX                                            295
#define SBK_QtCore_IDX_COUNT                                         296

// This variable stores all python types exported by this module
extern PyTypeObject** SbkPySide_QtCoreTypes;

// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject* SbkType< ::QtValidLicenseForOpenVGModule >() { return SbkPySide_QtCoreTypes[SBK_QTVALIDLICENSEFOROPENVGMODULE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QtValidLicenseForMultimediaModule >() { return SbkPySide_QtCoreTypes[SBK_QTVALIDLICENSEFORMULTIMEDIAMODULE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QtMsgType >() { return SbkPySide_QtCoreTypes[SBK_QTMSGTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide_QtCoreTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ShortcutContext >() { return SbkPySide_QtCoreTypes[SBK_QT_SHORTCUTCONTEXT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::CheckState >() { return SbkPySide_QtCoreTypes[SBK_QT_CHECKSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::FocusPolicy >() { return SbkPySide_QtCoreTypes[SBK_QT_FOCUSPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::GestureType >() { return SbkPySide_QtCoreTypes[SBK_QT_GESTURETYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::DropAction >() { return SbkPySide_QtCoreTypes[SBK_QT_DROPACTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::DropAction> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_DROPACTION__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WindowType >() { return SbkPySide_QtCoreTypes[SBK_QT_WINDOWTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::WindowType> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_WINDOWTYPE__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::DateFormat >() { return SbkPySide_QtCoreTypes[SBK_QT_DATEFORMAT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TextFormat >() { return SbkPySide_QtCoreTypes[SBK_QT_TEXTFORMAT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::PenJoinStyle >() { return SbkPySide_QtCoreTypes[SBK_QT_PENJOINSTYLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::GestureFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_GESTUREFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::GestureFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_GESTUREFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::CaseSensitivity >() { return SbkPySide_QtCoreTypes[SBK_QT_CASESENSITIVITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::EventPriority >() { return SbkPySide_QtCoreTypes[SBK_QT_EVENTPRIORITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ImageConversionFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_IMAGECONVERSIONFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::ImageConversionFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_IMAGECONVERSIONFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::GestureState >() { return SbkPySide_QtCoreTypes[SBK_QT_GESTURESTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::BGMode >() { return SbkPySide_QtCoreTypes[SBK_QT_BGMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ConnectionType >() { return SbkPySide_QtCoreTypes[SBK_QT_CONNECTIONTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ToolBarArea >() { return SbkPySide_QtCoreTypes[SBK_QT_TOOLBARAREA_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::ToolBarArea> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_TOOLBARAREA__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::CoordinateSystem >() { return SbkPySide_QtCoreTypes[SBK_QT_COORDINATESYSTEM_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::SizeMode >() { return SbkPySide_QtCoreTypes[SBK_QT_SIZEMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::FocusReason >() { return SbkPySide_QtCoreTypes[SBK_QT_FOCUSREASON_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::Modifier >() { return SbkPySide_QtCoreTypes[SBK_QT_MODIFIER_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TileRule >() { return SbkPySide_QtCoreTypes[SBK_QT_TILERULE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WhiteSpaceMode >() { return SbkPySide_QtCoreTypes[SBK_QT_WHITESPACEMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::AspectRatioMode >() { return SbkPySide_QtCoreTypes[SBK_QT_ASPECTRATIOMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::SizeHint >() { return SbkPySide_QtCoreTypes[SBK_QT_SIZEHINT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::AlignmentFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_ALIGNMENTFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::AlignmentFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_ALIGNMENTFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ContextMenuPolicy >() { return SbkPySide_QtCoreTypes[SBK_QT_CONTEXTMENUPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::DockWidgetArea >() { return SbkPySide_QtCoreTypes[SBK_QT_DOCKWIDGETAREA_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::DockWidgetArea> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_DOCKWIDGETAREA__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::UIEffect >() { return SbkPySide_QtCoreTypes[SBK_QT_UIEFFECT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::AnchorPoint >() { return SbkPySide_QtCoreTypes[SBK_QT_ANCHORPOINT_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::GlobalColor >() { return SbkPySide_QtCoreTypes[SBK_QT_GLOBALCOLOR_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::KeyboardModifier >() { return SbkPySide_QtCoreTypes[SBK_QT_KEYBOARDMODIFIER_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::KeyboardModifier> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_KEYBOARDMODIFIER__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::NavigationMode >() { return SbkPySide_QtCoreTypes[SBK_QT_NAVIGATIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ItemDataRole >() { return SbkPySide_QtCoreTypes[SBK_QT_ITEMDATAROLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ScrollBarPolicy >() { return SbkPySide_QtCoreTypes[SBK_QT_SCROLLBARPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::InputMethodHint >() { return SbkPySide_QtCoreTypes[SBK_QT_INPUTMETHODHINT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::InputMethodHint> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_INPUTMETHODHINT__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::AnchorAttribute >() { return SbkPySide_QtCoreTypes[SBK_QT_ANCHORATTRIBUTE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WindowModality >() { return SbkPySide_QtCoreTypes[SBK_QT_WINDOWMODALITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::SortOrder >() { return SbkPySide_QtCoreTypes[SBK_QT_SORTORDER_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::PenStyle >() { return SbkPySide_QtCoreTypes[SBK_QT_PENSTYLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ItemFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_ITEMFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::ItemFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_ITEMFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::Axis >() { return SbkPySide_QtCoreTypes[SBK_QT_AXIS_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TransformationMode >() { return SbkPySide_QtCoreTypes[SBK_QT_TRANSFORMATIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WindowFrameSection >() { return SbkPySide_QtCoreTypes[SBK_QT_WINDOWFRAMESECTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::HitTestAccuracy >() { return SbkPySide_QtCoreTypes[SBK_QT_HITTESTACCURACY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::CursorShape >() { return SbkPySide_QtCoreTypes[SBK_QT_CURSORSHAPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ItemSelectionMode >() { return SbkPySide_QtCoreTypes[SBK_QT_ITEMSELECTIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::Orientation >() { return SbkPySide_QtCoreTypes[SBK_QT_ORIENTATION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::Orientation> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_ORIENTATION__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::InputMethodQuery >() { return SbkPySide_QtCoreTypes[SBK_QT_INPUTMETHODQUERY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TimeSpec >() { return SbkPySide_QtCoreTypes[SBK_QT_TIMESPEC_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ArrowType >() { return SbkPySide_QtCoreTypes[SBK_QT_ARROWTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::FillRule >() { return SbkPySide_QtCoreTypes[SBK_QT_FILLRULE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::MaskMode >() { return SbkPySide_QtCoreTypes[SBK_QT_MASKMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WindowState >() { return SbkPySide_QtCoreTypes[SBK_QT_WINDOWSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::WindowState> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_WINDOWSTATE__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ToolBarAreaSizes >() { return SbkPySide_QtCoreTypes[SBK_QT_TOOLBARAREASIZES_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::Corner >() { return SbkPySide_QtCoreTypes[SBK_QT_CORNER_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::DayOfWeek >() { return SbkPySide_QtCoreTypes[SBK_QT_DAYOFWEEK_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ClipOperation >() { return SbkPySide_QtCoreTypes[SBK_QT_CLIPOPERATION_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::LayoutDirection >() { return SbkPySide_QtCoreTypes[SBK_QT_LAYOUTDIRECTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ToolButtonStyle >() { return SbkPySide_QtCoreTypes[SBK_QT_TOOLBUTTONSTYLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::DockWidgetAreaSizes >() { return SbkPySide_QtCoreTypes[SBK_QT_DOCKWIDGETAREASIZES_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::Key >() { return SbkPySide_QtCoreTypes[SBK_QT_KEY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::ApplicationAttribute >() { return SbkPySide_QtCoreTypes[SBK_QT_APPLICATIONATTRIBUTE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TextFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_TEXTFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::BrushStyle >() { return SbkPySide_QtCoreTypes[SBK_QT_BRUSHSTYLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::WidgetAttribute >() { return SbkPySide_QtCoreTypes[SBK_QT_WIDGETATTRIBUTE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TouchPointState >() { return SbkPySide_QtCoreTypes[SBK_QT_TOUCHPOINTSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TextInteractionFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_TEXTINTERACTIONFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::TextInteractionFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_TEXTINTERACTIONFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::MouseButton >() { return SbkPySide_QtCoreTypes[SBK_QT_MOUSEBUTTON_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::MouseButton> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_MOUSEBUTTON__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::MatchFlag >() { return SbkPySide_QtCoreTypes[SBK_QT_MATCHFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Qt::MatchFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QT_MATCHFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::PenCapStyle >() { return SbkPySide_QtCoreTypes[SBK_QT_PENCAPSTYLE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Qt::TextElideMode >() { return SbkPySide_QtCoreTypes[SBK_QT_TEXTELIDEMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextBoundaryFinder::BoundaryReason >() { return SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QTextBoundaryFinder::BoundaryReason> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTBOUNDARYFINDER_BOUNDARYREASON__IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextBoundaryFinder::BoundaryType >() { return SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_BOUNDARYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextBoundaryFinder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QRectF >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QRECTF_IDX]); }
template<> inline PyTypeObject* SbkType< ::QRect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QRECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSizeF >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSIZEF_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSize >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSIZE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMargins >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMARGINS_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLineF::IntersectType >() { return SbkPySide_QtCoreTypes[SBK_QLINEF_INTERSECTTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLineF >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QLINEF_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QLINE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPointF >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPOINTF_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPoint >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPOINT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QElapsedTimer::ClockType >() { return SbkPySide_QtCoreTypes[SBK_QELAPSEDTIMER_CLOCKTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QElapsedTimer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QELAPSEDTIMER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QCryptographicHash::Algorithm >() { return SbkPySide_QtCoreTypes[SBK_QCRYPTOGRAPHICHASH_ALGORITHM_IDX]; }
template<> inline PyTypeObject* SbkType< ::QCryptographicHash >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QCRYPTOGRAPHICHASH_IDX]); }
template<> inline PyTypeObject* SbkType< ::QByteArrayMatcher >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QBYTEARRAYMATCHER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QBitArray >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QBITARRAY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QProcessEnvironment >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPROCESSENVIRONMENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngineIterator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINEITERATOR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngineHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINEHANDLER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine::FileName >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILENAME_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine::FileTime >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILETIME_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine::FileOwner >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILEOWNER_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine::Extension >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_EXTENSION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine::FileFlag >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILEFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QAbstractFileEngine::FileFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QABSTRACTFILEENGINE_FILEFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractFileEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFSFileEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFSFILEENGINE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDir::Filter >() { return SbkPySide_QtCoreTypes[SBK_QDIR_FILTER_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QDir::Filter> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIR_FILTER__IDX]; }
template<> inline PyTypeObject* SbkType< ::QDir::SortFlag >() { return SbkPySide_QtCoreTypes[SBK_QDIR_SORTFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QDir::SortFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIR_SORTFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QDir >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDIR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDirIterator::IteratorFlag >() { return SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_ITERATORFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QDirIterator::IteratorFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIRITERATOR_ITERATORFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QDirIterator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFileInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFILEINFO_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWriteLocker >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QWRITELOCKER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QReadLocker >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QREADLOCKER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QReadWriteLock::RecursionMode >() { return SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_RECURSIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QReadWriteLock >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSemaphore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSEMAPHORE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWaitCondition >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QWAITCONDITION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextStreamManipulator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTSTREAMMANIPULATOR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLocale::MeasurementSystem >() { return SbkPySide_QtCoreTypes[SBK_QLOCALE_MEASUREMENTSYSTEM_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocale::NumberOption >() { return SbkPySide_QtCoreTypes[SBK_QLOCALE_NUMBEROPTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QLocale::NumberOption> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QLOCALE_NUMBEROPTION__IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocale::FormatType >() { return SbkPySide_QtCoreTypes[SBK_QLOCALE_FORMATTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocale::Country >() { return SbkPySide_QtCoreTypes[SBK_QLOCALE_COUNTRY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocale::Language >() { return SbkPySide_QtCoreTypes[SBK_QLOCALE_LANGUAGE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocale >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QLOCALE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QResource >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QRESOURCE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSystemLocale::QueryType >() { return SbkPySide_QtCoreTypes[SBK_QSYSTEMLOCALE_QUERYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSystemLocale >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSYSTEMLOCALE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMutexLocker >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMUTEXLOCKER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMutex::RecursionMode >() { return SbkPySide_QtCoreTypes[SBK_QMUTEX_RECURSIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QMutex >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMUTEX_IDX]); }
template<> inline PyTypeObject* SbkType< ::QRunnable >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QRUNNABLE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QUuid::Variant >() { return SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QUuid::Version >() { return SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QUuid >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QUUID_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamWriter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMWRITER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamReader::Error >() { return SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_ERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QXmlStreamReader::TokenType >() { return SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_TOKENTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QXmlStreamReader::ReadElementTextBehaviour >() { return SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QXmlStreamReader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamEntityResolver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMENTITYRESOLVER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamEntityDeclaration >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMENTITYDECLARATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamNotationDeclaration >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMNOTATIONDECLARATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamNamespaceDeclaration >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMNAMESPACEDECLARATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamAttributes >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMATTRIBUTES_IDX]); }
template<> inline PyTypeObject* SbkType< ::QXmlStreamAttribute >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QXMLSTREAMATTRIBUTE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFactoryInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFACTORYINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QRegExp::PatternSyntax >() { return SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX]; }
template<> inline PyTypeObject* SbkType< ::QRegExp::CaretMode >() { return SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QRegExp >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QREGEXP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextDecoder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTDECODER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextEncoder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTENCODER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextCodec::ConversionFlag >() { return SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_CONVERSIONFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QTextCodec::ConversionFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTCODEC_CONVERSIONFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextCodec >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextCodec::ConverterState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_CONVERTERSTATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSystemSemaphore::AccessMode >() { return SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSystemSemaphore::SystemSemaphoreError >() { return SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSystemSemaphore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMetaClassInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMETACLASSINFO_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMetaProperty >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMETAPROPERTY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMetaEnum >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMETAENUM_IDX]); }
template<> inline PyTypeObject* SbkType< ::QEvent::Type >() { return SbkPySide_QtCoreTypes[SBK_QEVENT_TYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDynamicPropertyChangeEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDYNAMICPROPERTYCHANGEEVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QChildEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QCHILDEVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTimerEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTIMEREVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QBasicTimer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QBASICTIMER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPersistentModelIndex >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPERSISTENTMODELINDEX_IDX]); }
template<> inline PyTypeObject* SbkType< ::QModelIndex >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMODELINDEX_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDateTime >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDATETIME_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTime >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTIME_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDate::MonthNameType >() { return SbkPySide_QtCoreTypes[SBK_QDATE_MONTHNAMETYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QDate >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QDataStream::FloatingPointPrecision >() { return SbkPySide_QtCoreTypes[SBK_QDATASTREAM_FLOATINGPOINTPRECISION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QDataStream::Version >() { return SbkPySide_QtCoreTypes[SBK_QDATASTREAM_VERSION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QDataStream::Status >() { return SbkPySide_QtCoreTypes[SBK_QDATASTREAM_STATUS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QDataStream >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QDATASTREAM_IDX]); }
template<> inline PyTypeObject* SbkType< ::QEasingCurve::Type >() { return SbkPySide_QtCoreTypes[SBK_QEASINGCURVE_TYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QEasingCurve >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QEASINGCURVE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QObject >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractTransition >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTTRANSITION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSignalTransition >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSIGNALTRANSITION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QEventTransition >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QEVENTTRANSITION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QState::ChildMode >() { return SbkPySide_QtCoreTypes[SBK_QSTATE_CHILDMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSTATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QStateMachine::Error >() { return SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_ERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QStateMachine::EventPriority >() { return SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_EVENTPRIORITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QStateMachine::RestorePolicy >() { return SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_RESTOREPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QStateMachine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QStateMachine::WrappedEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_WRAPPEDEVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QStateMachine::SignalEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_SIGNALEVENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHistoryState::HistoryType >() { return SbkPySide_QtCoreTypes[SBK_QHISTORYSTATE_HISTORYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHistoryState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QHISTORYSTATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFinalState >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFINALSTATE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QThreadPool >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTHREADPOOL_IDX]); }
template<> inline PyTypeObject* SbkType< ::QThread::Priority >() { return SbkPySide_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QThread >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTHREAD_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractItemModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTITEMMODEL_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractListModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTLISTMODEL_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTTABLEMODEL_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSettings::Format >() { return SbkPySide_QtCoreTypes[SBK_QSETTINGS_FORMAT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSettings::Status >() { return SbkPySide_QtCoreTypes[SBK_QSETTINGS_STATUS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSettings::Scope >() { return SbkPySide_QtCoreTypes[SBK_QSETTINGS_SCOPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSettings >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSETTINGS_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractEventDispatcher >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTEVENTDISPATCHER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPluginLoader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPLUGINLOADER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QEventLoop::ProcessEventsFlag >() { return SbkPySide_QtCoreTypes[SBK_QEVENTLOOP_PROCESSEVENTSFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QEventLoop::ProcessEventsFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QEVENTLOOP_PROCESSEVENTSFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QEventLoop >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QEVENTLOOP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QCoreApplication::Encoding >() { return SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_ENCODING_IDX]; }
template<> inline PyTypeObject* SbkType< ::QCoreApplication >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFileSystemWatcher >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFILESYSTEMWATCHER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QIODevice::OpenModeFlag >() { return SbkPySide_QtCoreTypes[SBK_QIODEVICE_OPENMODEFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QIODevice::OpenModeFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QIODEVICE_OPENMODEFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QIODevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFile::FileError >() { return SbkPySide_QtCoreTypes[SBK_QFILE_FILEERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFile::MemoryMapFlags >() { return SbkPySide_QtCoreTypes[SBK_QFILE_MEMORYMAPFLAGS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFile::Permission >() { return SbkPySide_QtCoreTypes[SBK_QFILE_PERMISSION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QFile::Permission> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QFILE_PERMISSION__IDX]; }
template<> inline PyTypeObject* SbkType< ::QFile >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QFILE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTemporaryFile >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEMPORARYFILE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTextStream::RealNumberNotation >() { return SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextStream::NumberFlag >() { return SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_NUMBERFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QTextStream::NumberFlag> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTSTREAM_NUMBERFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextStream::FieldAlignment >() { return SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextStream::Status >() { return SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_STATUS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTextStream >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_IDX]); }
template<> inline PyTypeObject* SbkType< ::QProcess::ProcessError >() { return SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QProcess::ProcessChannelMode >() { return SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNELMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QProcess::ProcessChannel >() { return SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNEL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QProcess::ProcessState >() { return SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QProcess::ExitStatus >() { return SbkPySide_QtCoreTypes[SBK_QPROCESS_EXITSTATUS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QProcess >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPROCESS_IDX]); }
template<> inline PyTypeObject* SbkType< ::QBuffer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QBUFFER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractAnimation::Direction >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTANIMATION_DIRECTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractAnimation::DeletionPolicy >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTANIMATION_DELETIONPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractAnimation::State >() { return SbkPySide_QtCoreTypes[SBK_QABSTRACTANIMATION_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTANIMATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QVariantAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QVARIANTANIMATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPropertyAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPROPERTYANIMATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QPauseAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPAUSEANIMATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QANIMATIONGROUP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSequentialAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSEQUENTIALANIMATIONGROUP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QParallelAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QPARALLELANIMATIONGROUP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTranslator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTRANSLATOR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTimer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTIMER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTimeLine::Direction >() { return SbkPySide_QtCoreTypes[SBK_QTIMELINE_DIRECTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTimeLine::CurveShape >() { return SbkPySide_QtCoreTypes[SBK_QTIMELINE_CURVESHAPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTimeLine::State >() { return SbkPySide_QtCoreTypes[SBK_QTIMELINE_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QTimeLine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QTIMELINE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSocketNotifier::Type >() { return SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSocketNotifier >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSignalMapper >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSIGNALMAPPER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMimeData >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMIMEDATA_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLibraryInfo::LibraryLocation >() { return SbkPySide_QtCoreTypes[SBK_QLIBRARYINFO_LIBRARYLOCATION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLibraryInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QLIBRARYINFO_IDX]); }
template<> inline PyTypeObject* SbkType< ::QByteArray >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QBYTEARRAY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QUrl::ParsingMode >() { return SbkPySide_QtCoreTypes[SBK_QURL_PARSINGMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QUrl::FormattingOption >() { return SbkPySide_QtCoreTypes[SBK_QURL_FORMATTINGOPTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QUrl::FormattingOption> >() { return SbkPySide_QtCoreTypes[SBK_QFLAGS_QURL_FORMATTINGOPTION__IDX]; }
template<> inline PyTypeObject* SbkType< ::QUrl >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QURL_IDX]); }
template<> inline PyTypeObject* SbkType< ::QGenericArgument >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QGENERICARGUMENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMetaMethod::Access >() { return SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_ACCESS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QMetaMethod::MethodType >() { return SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_METHODTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QMetaMethod >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_IDX]); }
template<> inline PyTypeObject* SbkType< ::QMetaObject::Call >() { return SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_CALL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QMetaObject >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QGenericReturnArgument >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QGENERICRETURNARGUMENT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSysInfo::Endian >() { return SbkPySide_QtCoreTypes[SBK_QSYSINFO_ENDIAN_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSysInfo::Sizes >() { return SbkPySide_QtCoreTypes[SBK_QSYSINFO_SIZES_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSysInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtCoreTypes[SBK_QSYSINFO_IDX]); }

template<>
inline PyObject* createWrapper<QObject >(const QObject* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QObject* value = const_cast<QObject* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QObject >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractTransition >(const QAbstractTransition* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractTransition* value = const_cast<QAbstractTransition* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractTransition >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSignalTransition >(const QSignalTransition* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSignalTransition* value = const_cast<QSignalTransition* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSignalTransition >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QEventTransition >(const QEventTransition* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QEventTransition* value = const_cast<QEventTransition* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QEventTransition >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractState >(const QAbstractState* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractState* value = const_cast<QAbstractState* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractState >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QState >(const QState* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QState* value = const_cast<QState* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QState >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QStateMachine >(const QStateMachine* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QStateMachine* value = const_cast<QStateMachine* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QStateMachine >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHistoryState >(const QHistoryState* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QHistoryState* value = const_cast<QHistoryState* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QHistoryState >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QFinalState >(const QFinalState* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QFinalState* value = const_cast<QFinalState* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QFinalState >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QThreadPool >(const QThreadPool* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QThreadPool* value = const_cast<QThreadPool* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QThreadPool >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QThread >(const QThread* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QThread* value = const_cast<QThread* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QThread >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractItemModel >(const QAbstractItemModel* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractItemModel* value = const_cast<QAbstractItemModel* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractItemModel >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractListModel >(const QAbstractListModel* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractListModel* value = const_cast<QAbstractListModel* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractListModel >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractTableModel >(const QAbstractTableModel* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractTableModel* value = const_cast<QAbstractTableModel* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractTableModel >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSettings >(const QSettings* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSettings* value = const_cast<QSettings* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSettings >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractEventDispatcher >(const QAbstractEventDispatcher* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractEventDispatcher* value = const_cast<QAbstractEventDispatcher* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractEventDispatcher >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QPluginLoader >(const QPluginLoader* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QPluginLoader* value = const_cast<QPluginLoader* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QPluginLoader >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QEventLoop >(const QEventLoop* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QEventLoop* value = const_cast<QEventLoop* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QEventLoop >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QCoreApplication >(const QCoreApplication* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QCoreApplication* value = const_cast<QCoreApplication* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QCoreApplication >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QFileSystemWatcher >(const QFileSystemWatcher* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QFileSystemWatcher* value = const_cast<QFileSystemWatcher* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QFileSystemWatcher >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QIODevice >(const QIODevice* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QIODevice* value = const_cast<QIODevice* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QIODevice >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QFile >(const QFile* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QFile* value = const_cast<QFile* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QFile >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTemporaryFile >(const QTemporaryFile* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTemporaryFile* value = const_cast<QTemporaryFile* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTemporaryFile >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QProcess >(const QProcess* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QProcess* value = const_cast<QProcess* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QProcess >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QBuffer >(const QBuffer* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QBuffer* value = const_cast<QBuffer* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QBuffer >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractAnimation >(const QAbstractAnimation* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractAnimation* value = const_cast<QAbstractAnimation* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractAnimation >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QVariantAnimation >(const QVariantAnimation* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QVariantAnimation* value = const_cast<QVariantAnimation* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QVariantAnimation >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QPropertyAnimation >(const QPropertyAnimation* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QPropertyAnimation* value = const_cast<QPropertyAnimation* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QPropertyAnimation >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QPauseAnimation >(const QPauseAnimation* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QPauseAnimation* value = const_cast<QPauseAnimation* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QPauseAnimation >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAnimationGroup >(const QAnimationGroup* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAnimationGroup* value = const_cast<QAnimationGroup* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAnimationGroup >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSequentialAnimationGroup >(const QSequentialAnimationGroup* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSequentialAnimationGroup* value = const_cast<QSequentialAnimationGroup* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSequentialAnimationGroup >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QParallelAnimationGroup >(const QParallelAnimationGroup* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QParallelAnimationGroup* value = const_cast<QParallelAnimationGroup* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QParallelAnimationGroup >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTranslator >(const QTranslator* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTranslator* value = const_cast<QTranslator* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTranslator >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTimer >(const QTimer* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTimer* value = const_cast<QTimer* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTimer >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTimeLine >(const QTimeLine* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTimeLine* value = const_cast<QTimeLine* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTimeLine >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSocketNotifier >(const QSocketNotifier* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSocketNotifier* value = const_cast<QSocketNotifier* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSocketNotifier >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSignalMapper >(const QSignalMapper* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSignalMapper* value = const_cast<QSignalMapper* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSignalMapper >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QMimeData >(const QMimeData* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QMimeData* value = const_cast<QMimeData* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QMimeData >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
// Generated converters declarations ----------------------------------

template<>
struct Converter< ::QtValidLicenseForOpenVGModule > : EnumConverter< ::QtValidLicenseForOpenVGModule >
{
};

template<>
struct Converter< ::QtValidLicenseForMultimediaModule > : EnumConverter< ::QtValidLicenseForMultimediaModule >
{
};

template<>
struct Converter< ::QtMsgType > : EnumConverter< ::QtMsgType >
{
};

template<>
struct Converter< ::QtConcurrent::ReduceOption > : EnumConverter< ::QtConcurrent::ReduceOption >
{
};
template<>
struct Converter< ::QFlags<QtConcurrent::ReduceOption> > : QFlagsConverter< ::QFlags<QtConcurrent::ReduceOption> >
{
};

template<>
struct Converter< ::Qt::ShortcutContext > : EnumConverter< ::Qt::ShortcutContext >
{
};

template<>
struct Converter< ::Qt::CheckState > : EnumConverter< ::Qt::CheckState >
{
};

template<>
struct Converter< ::Qt::FocusPolicy > : EnumConverter< ::Qt::FocusPolicy >
{
};

template<>
struct Converter< ::Qt::GestureType > : EnumConverter< ::Qt::GestureType >
{
};

template<>
struct Converter< ::Qt::DropAction > : EnumConverter< ::Qt::DropAction >
{
};
template<>
struct Converter< ::QFlags<Qt::DropAction> > : QFlagsConverter< ::QFlags<Qt::DropAction> >
{
};

template<>
struct Converter< ::Qt::WindowType > : EnumConverter< ::Qt::WindowType >
{
};
template<>
struct Converter< ::QFlags<Qt::WindowType> > : QFlagsConverter< ::QFlags<Qt::WindowType> >
{
};

template<>
struct Converter< ::Qt::DateFormat > : EnumConverter< ::Qt::DateFormat >
{
};

template<>
struct Converter< ::Qt::TextFormat > : EnumConverter< ::Qt::TextFormat >
{
};

template<>
struct Converter< ::Qt::PenJoinStyle > : EnumConverter< ::Qt::PenJoinStyle >
{
};

template<>
struct Converter< ::Qt::GestureFlag > : EnumConverter< ::Qt::GestureFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::GestureFlag> > : QFlagsConverter< ::QFlags<Qt::GestureFlag> >
{
};

template<>
struct Converter< ::Qt::CaseSensitivity > : EnumConverter< ::Qt::CaseSensitivity >
{
};

template<>
struct Converter< ::Qt::EventPriority > : EnumConverter< ::Qt::EventPriority >
{
};

template<>
struct Converter< ::Qt::ImageConversionFlag > : EnumConverter< ::Qt::ImageConversionFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::ImageConversionFlag> > : QFlagsConverter< ::QFlags<Qt::ImageConversionFlag> >
{
};

template<>
struct Converter< ::Qt::GestureState > : EnumConverter< ::Qt::GestureState >
{
};

template<>
struct Converter< ::Qt::BGMode > : EnumConverter< ::Qt::BGMode >
{
};

template<>
struct Converter< ::Qt::ConnectionType > : EnumConverter< ::Qt::ConnectionType >
{
};

template<>
struct Converter< ::Qt::ToolBarArea > : EnumConverter< ::Qt::ToolBarArea >
{
};
template<>
struct Converter< ::QFlags<Qt::ToolBarArea> > : QFlagsConverter< ::QFlags<Qt::ToolBarArea> >
{
};

template<>
struct Converter< ::Qt::CoordinateSystem > : EnumConverter< ::Qt::CoordinateSystem >
{
};

template<>
struct Converter< ::Qt::SizeMode > : EnumConverter< ::Qt::SizeMode >
{
};

template<>
struct Converter< ::Qt::FocusReason > : EnumConverter< ::Qt::FocusReason >
{
};

template<>
struct Converter< ::Qt::Modifier > : EnumConverter< ::Qt::Modifier >
{
};

template<>
struct Converter< ::Qt::TileRule > : EnumConverter< ::Qt::TileRule >
{
};

template<>
struct Converter< ::Qt::WhiteSpaceMode > : EnumConverter< ::Qt::WhiteSpaceMode >
{
};

template<>
struct Converter< ::Qt::AspectRatioMode > : EnumConverter< ::Qt::AspectRatioMode >
{
};

template<>
struct Converter< ::Qt::SizeHint > : EnumConverter< ::Qt::SizeHint >
{
};

template<>
struct Converter< ::Qt::AlignmentFlag > : EnumConverter< ::Qt::AlignmentFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::AlignmentFlag> > : QFlagsConverter< ::QFlags<Qt::AlignmentFlag> >
{
};

template<>
struct Converter< ::Qt::ContextMenuPolicy > : EnumConverter< ::Qt::ContextMenuPolicy >
{
};

template<>
struct Converter< ::Qt::DockWidgetArea > : EnumConverter< ::Qt::DockWidgetArea >
{
};
template<>
struct Converter< ::QFlags<Qt::DockWidgetArea> > : QFlagsConverter< ::QFlags<Qt::DockWidgetArea> >
{
};

template<>
struct Converter< ::Qt::UIEffect > : EnumConverter< ::Qt::UIEffect >
{
};

template<>
struct Converter< ::Qt::AnchorPoint > : EnumConverter< ::Qt::AnchorPoint >
{
};

template<>
struct Converter< ::Qt::GlobalColor > : EnumConverter< ::Qt::GlobalColor >
{
};

template<>
struct Converter< ::Qt::KeyboardModifier > : EnumConverter< ::Qt::KeyboardModifier >
{
};
template<>
struct Converter< ::QFlags<Qt::KeyboardModifier> > : QFlagsConverter< ::QFlags<Qt::KeyboardModifier> >
{
};

template<>
struct Converter< ::Qt::NavigationMode > : EnumConverter< ::Qt::NavigationMode >
{
};

template<>
struct Converter< ::Qt::ItemDataRole > : EnumConverter< ::Qt::ItemDataRole >
{
};

template<>
struct Converter< ::Qt::ScrollBarPolicy > : EnumConverter< ::Qt::ScrollBarPolicy >
{
};

template<>
struct Converter< ::Qt::InputMethodHint > : EnumConverter< ::Qt::InputMethodHint >
{
};
template<>
struct Converter< ::QFlags<Qt::InputMethodHint> > : QFlagsConverter< ::QFlags<Qt::InputMethodHint> >
{
};

template<>
struct Converter< ::Qt::AnchorAttribute > : EnumConverter< ::Qt::AnchorAttribute >
{
};

template<>
struct Converter< ::Qt::WindowModality > : EnumConverter< ::Qt::WindowModality >
{
};

template<>
struct Converter< ::Qt::SortOrder > : EnumConverter< ::Qt::SortOrder >
{
};

template<>
struct Converter< ::Qt::PenStyle > : EnumConverter< ::Qt::PenStyle >
{
};

template<>
struct Converter< ::Qt::ItemFlag > : EnumConverter< ::Qt::ItemFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::ItemFlag> > : QFlagsConverter< ::QFlags<Qt::ItemFlag> >
{
};

template<>
struct Converter< ::Qt::Axis > : EnumConverter< ::Qt::Axis >
{
};

template<>
struct Converter< ::Qt::TransformationMode > : EnumConverter< ::Qt::TransformationMode >
{
};

template<>
struct Converter< ::Qt::WindowFrameSection > : EnumConverter< ::Qt::WindowFrameSection >
{
};

template<>
struct Converter< ::Qt::HitTestAccuracy > : EnumConverter< ::Qt::HitTestAccuracy >
{
};

template<>
struct Converter< ::Qt::CursorShape > : EnumConverter< ::Qt::CursorShape >
{
};

template<>
struct Converter< ::Qt::ItemSelectionMode > : EnumConverter< ::Qt::ItemSelectionMode >
{
};

template<>
struct Converter< ::Qt::Orientation > : EnumConverter< ::Qt::Orientation >
{
};
template<>
struct Converter< ::QFlags<Qt::Orientation> > : QFlagsConverter< ::QFlags<Qt::Orientation> >
{
};

template<>
struct Converter< ::Qt::InputMethodQuery > : EnumConverter< ::Qt::InputMethodQuery >
{
};

template<>
struct Converter< ::Qt::TimeSpec > : EnumConverter< ::Qt::TimeSpec >
{
};

template<>
struct Converter< ::Qt::ArrowType > : EnumConverter< ::Qt::ArrowType >
{
};

template<>
struct Converter< ::Qt::FillRule > : EnumConverter< ::Qt::FillRule >
{
};

template<>
struct Converter< ::Qt::MaskMode > : EnumConverter< ::Qt::MaskMode >
{
};

template<>
struct Converter< ::Qt::WindowState > : EnumConverter< ::Qt::WindowState >
{
};
template<>
struct Converter< ::QFlags<Qt::WindowState> > : QFlagsConverter< ::QFlags<Qt::WindowState> >
{
};

template<>
struct Converter< ::Qt::ToolBarAreaSizes > : EnumConverter< ::Qt::ToolBarAreaSizes >
{
};

template<>
struct Converter< ::Qt::Corner > : EnumConverter< ::Qt::Corner >
{
};

template<>
struct Converter< ::Qt::DayOfWeek > : EnumConverter< ::Qt::DayOfWeek >
{
};

template<>
struct Converter< ::Qt::ClipOperation > : EnumConverter< ::Qt::ClipOperation >
{
};

template<>
struct Converter< ::Qt::LayoutDirection > : EnumConverter< ::Qt::LayoutDirection >
{
};

template<>
struct Converter< ::Qt::ToolButtonStyle > : EnumConverter< ::Qt::ToolButtonStyle >
{
};

template<>
struct Converter< ::Qt::DockWidgetAreaSizes > : EnumConverter< ::Qt::DockWidgetAreaSizes >
{
};

template<>
struct Converter< ::Qt::Key > : EnumConverter< ::Qt::Key >
{
};

template<>
struct Converter< ::Qt::ApplicationAttribute > : EnumConverter< ::Qt::ApplicationAttribute >
{
};

template<>
struct Converter< ::Qt::TextFlag > : EnumConverter< ::Qt::TextFlag >
{
};

template<>
struct Converter< ::Qt::BrushStyle > : EnumConverter< ::Qt::BrushStyle >
{
};

template<>
struct Converter< ::Qt::WidgetAttribute > : EnumConverter< ::Qt::WidgetAttribute >
{
};

template<>
struct Converter< ::Qt::TouchPointState > : EnumConverter< ::Qt::TouchPointState >
{
};

template<>
struct Converter< ::Qt::TextInteractionFlag > : EnumConverter< ::Qt::TextInteractionFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::TextInteractionFlag> > : QFlagsConverter< ::QFlags<Qt::TextInteractionFlag> >
{
};

template<>
struct Converter< ::Qt::MouseButton > : EnumConverter< ::Qt::MouseButton >
{
};
template<>
struct Converter< ::QFlags<Qt::MouseButton> > : QFlagsConverter< ::QFlags<Qt::MouseButton> >
{
};

template<>
struct Converter< ::Qt::MatchFlag > : EnumConverter< ::Qt::MatchFlag >
{
};
template<>
struct Converter< ::QFlags<Qt::MatchFlag> > : QFlagsConverter< ::QFlags<Qt::MatchFlag> >
{
};

template<>
struct Converter< ::Qt::PenCapStyle > : EnumConverter< ::Qt::PenCapStyle >
{
};

template<>
struct Converter< ::Qt::TextElideMode > : EnumConverter< ::Qt::TextElideMode >
{
};

template<>
struct Converter< ::QTextBoundaryFinder::BoundaryReason > : EnumConverter< ::QTextBoundaryFinder::BoundaryReason >
{
};
template<>
struct Converter< ::QFlags<QTextBoundaryFinder::BoundaryReason> > : QFlagsConverter< ::QFlags<QTextBoundaryFinder::BoundaryReason> >
{
};

template<>
struct Converter< ::QTextBoundaryFinder::BoundaryType > : EnumConverter< ::QTextBoundaryFinder::BoundaryType >
{
};

template<>
struct Converter< ::QTextBoundaryFinder > : ValueTypeConverter< ::QTextBoundaryFinder >
{
};

template<>
struct Converter< ::QRectF > : ValueTypeConverter< ::QRectF >
{
    static ::QRectF toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QRect > : ValueTypeConverter< ::QRect >
{
};

template<>
struct Converter< ::QSizeF > : ValueTypeConverter< ::QSizeF >
{
    static ::QSizeF toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QSize > : ValueTypeConverter< ::QSize >
{
};

template<>
struct Converter< ::QMargins > : ValueTypeConverter< ::QMargins >
{
};

template<>
struct Converter< ::QLineF::IntersectType > : EnumConverter< ::QLineF::IntersectType >
{
};

template<>
struct Converter< ::QLineF > : ValueTypeConverter< ::QLineF >
{
    static ::QLineF toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QLine > : ValueTypeConverter< ::QLine >
{
};

template<>
struct Converter< ::QPointF > : ValueTypeConverter< ::QPointF >
{
    static ::QPointF toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QPoint > : ValueTypeConverter< ::QPoint >
{
};

template<>
struct Converter< ::QElapsedTimer::ClockType > : EnumConverter< ::QElapsedTimer::ClockType >
{
};

template<>
struct Converter< ::QElapsedTimer > : ValueTypeConverter< ::QElapsedTimer >
{
};

template<>
struct Converter< ::QCryptographicHash::Algorithm > : EnumConverter< ::QCryptographicHash::Algorithm >
{
};

template<>
struct Converter< ::QCryptographicHash* > : ObjectTypeConverter< ::QCryptographicHash >
{
};

template<>
struct Converter< ::QCryptographicHash > : ObjectTypeReferenceConverter< ::QCryptographicHash >
{
};

template<>
struct Converter< ::QByteArrayMatcher > : ValueTypeConverter< ::QByteArrayMatcher >
{
};

template<>
struct Converter< ::QBitArray > : ValueTypeConverter< ::QBitArray >
{
};

template<>
struct Converter< ::QProcessEnvironment > : ValueTypeConverter< ::QProcessEnvironment >
{
};

template<>
struct Converter< ::QAbstractFileEngineIterator* > : ObjectTypeConverter< ::QAbstractFileEngineIterator >
{
};

template<>
struct Converter< ::QAbstractFileEngineIterator > : ObjectTypeReferenceConverter< ::QAbstractFileEngineIterator >
{
};

template<>
struct Converter< ::QAbstractFileEngineHandler* > : ObjectTypeConverter< ::QAbstractFileEngineHandler >
{
};

template<>
struct Converter< ::QAbstractFileEngineHandler > : ObjectTypeReferenceConverter< ::QAbstractFileEngineHandler >
{
};

template<>
struct Converter< ::QAbstractFileEngine::FileName > : EnumConverter< ::QAbstractFileEngine::FileName >
{
};

template<>
struct Converter< ::QAbstractFileEngine::FileTime > : EnumConverter< ::QAbstractFileEngine::FileTime >
{
};

template<>
struct Converter< ::QAbstractFileEngine::FileOwner > : EnumConverter< ::QAbstractFileEngine::FileOwner >
{
};

template<>
struct Converter< ::QAbstractFileEngine::Extension > : EnumConverter< ::QAbstractFileEngine::Extension >
{
};

template<>
struct Converter< ::QAbstractFileEngine::FileFlag > : EnumConverter< ::QAbstractFileEngine::FileFlag >
{
};
template<>
struct Converter< ::QFlags<QAbstractFileEngine::FileFlag> > : QFlagsConverter< ::QFlags<QAbstractFileEngine::FileFlag> >
{
};

template<>
struct Converter< ::QAbstractFileEngine* > : ObjectTypeConverter< ::QAbstractFileEngine >
{
};

template<>
struct Converter< ::QAbstractFileEngine > : ObjectTypeReferenceConverter< ::QAbstractFileEngine >
{
};

template<>
struct Converter< ::QFSFileEngine* > : ObjectTypeConverter< ::QFSFileEngine >
{
};

template<>
struct Converter< ::QFSFileEngine > : ObjectTypeReferenceConverter< ::QFSFileEngine >
{
};

template<>
struct Converter< ::QDir::Filter > : EnumConverter< ::QDir::Filter >
{
};
template<>
struct Converter< ::QFlags<QDir::Filter> > : QFlagsConverter< ::QFlags<QDir::Filter> >
{
};

template<>
struct Converter< ::QDir::SortFlag > : EnumConverter< ::QDir::SortFlag >
{
};
template<>
struct Converter< ::QFlags<QDir::SortFlag> > : QFlagsConverter< ::QFlags<QDir::SortFlag> >
{
};

template<>
struct Converter< ::QDir > : ValueTypeConverter< ::QDir >
{
    static ::QDir toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QDirIterator::IteratorFlag > : EnumConverter< ::QDirIterator::IteratorFlag >
{
};
template<>
struct Converter< ::QFlags<QDirIterator::IteratorFlag> > : QFlagsConverter< ::QFlags<QDirIterator::IteratorFlag> >
{
};

template<>
struct Converter< ::QDirIterator* > : ObjectTypeConverter< ::QDirIterator >
{
};

template<>
struct Converter< ::QDirIterator > : ObjectTypeReferenceConverter< ::QDirIterator >
{
};

template<>
struct Converter< ::QFileInfo > : ValueTypeConverter< ::QFileInfo >
{
    static ::QFileInfo toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QWriteLocker* > : ObjectTypeConverter< ::QWriteLocker >
{
};

template<>
struct Converter< ::QWriteLocker > : ObjectTypeReferenceConverter< ::QWriteLocker >
{
};

template<>
struct Converter< ::QReadLocker* > : ObjectTypeConverter< ::QReadLocker >
{
};

template<>
struct Converter< ::QReadLocker > : ObjectTypeReferenceConverter< ::QReadLocker >
{
};

template<>
struct Converter< ::QReadWriteLock::RecursionMode > : EnumConverter< ::QReadWriteLock::RecursionMode >
{
};

template<>
struct Converter< ::QReadWriteLock* > : ObjectTypeConverter< ::QReadWriteLock >
{
};

template<>
struct Converter< ::QReadWriteLock > : ObjectTypeReferenceConverter< ::QReadWriteLock >
{
};

template<>
struct Converter< ::QSemaphore* > : ObjectTypeConverter< ::QSemaphore >
{
};

template<>
struct Converter< ::QSemaphore > : ObjectTypeReferenceConverter< ::QSemaphore >
{
};

template<>
struct Converter< ::QWaitCondition* > : ObjectTypeConverter< ::QWaitCondition >
{
};

template<>
struct Converter< ::QWaitCondition > : ObjectTypeReferenceConverter< ::QWaitCondition >
{
};

template<>
struct Converter< ::QTextStreamManipulator > : ValueTypeConverter< ::QTextStreamManipulator >
{
};

template<>
struct Converter< ::QLocale::MeasurementSystem > : EnumConverter< ::QLocale::MeasurementSystem >
{
};

template<>
struct Converter< ::QLocale::NumberOption > : EnumConverter< ::QLocale::NumberOption >
{
};
template<>
struct Converter< ::QFlags<QLocale::NumberOption> > : QFlagsConverter< ::QFlags<QLocale::NumberOption> >
{
};

template<>
struct Converter< ::QLocale::FormatType > : EnumConverter< ::QLocale::FormatType >
{
};

template<>
struct Converter< ::QLocale::Country > : EnumConverter< ::QLocale::Country >
{
};

template<>
struct Converter< ::QLocale::Language > : EnumConverter< ::QLocale::Language >
{
};

template<>
struct Converter< ::QLocale > : ValueTypeConverter< ::QLocale >
{
    static ::QLocale toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QResource* > : ObjectTypeConverter< ::QResource >
{
};

template<>
struct Converter< ::QResource > : ObjectTypeReferenceConverter< ::QResource >
{
};

template<>
struct Converter< ::QSystemLocale::QueryType > : EnumConverter< ::QSystemLocale::QueryType >
{
};

template<>
struct Converter< ::QSystemLocale* > : ObjectTypeConverter< ::QSystemLocale >
{
};

template<>
struct Converter< ::QSystemLocale > : ObjectTypeReferenceConverter< ::QSystemLocale >
{
};

template<>
struct Converter< ::QMutexLocker* > : ObjectTypeConverter< ::QMutexLocker >
{
};

template<>
struct Converter< ::QMutexLocker > : ObjectTypeReferenceConverter< ::QMutexLocker >
{
};

template<>
struct Converter< ::QMutex::RecursionMode > : EnumConverter< ::QMutex::RecursionMode >
{
};

template<>
struct Converter< ::QMutex* > : ObjectTypeConverter< ::QMutex >
{
};

template<>
struct Converter< ::QMutex > : ObjectTypeReferenceConverter< ::QMutex >
{
};

template<>
struct Converter< ::QRunnable* > : ObjectTypeConverter< ::QRunnable >
{
};

template<>
struct Converter< ::QRunnable > : ObjectTypeReferenceConverter< ::QRunnable >
{
};

template<>
struct Converter< ::QUuid::Variant > : EnumConverter< ::QUuid::Variant >
{
};

template<>
struct Converter< ::QUuid::Version > : EnumConverter< ::QUuid::Version >
{
};

template<>
struct Converter< ::QUuid > : ValueTypeConverter< ::QUuid >
{
    static ::QUuid toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QXmlStreamWriter* > : ObjectTypeConverter< ::QXmlStreamWriter >
{
};

template<>
struct Converter< ::QXmlStreamWriter > : ObjectTypeReferenceConverter< ::QXmlStreamWriter >
{
};

template<>
struct Converter< ::QXmlStreamReader::Error > : EnumConverter< ::QXmlStreamReader::Error >
{
};

template<>
struct Converter< ::QXmlStreamReader::TokenType > : EnumConverter< ::QXmlStreamReader::TokenType >
{
};

template<>
struct Converter< ::QXmlStreamReader::ReadElementTextBehaviour > : EnumConverter< ::QXmlStreamReader::ReadElementTextBehaviour >
{
};

template<>
struct Converter< ::QXmlStreamReader* > : ObjectTypeConverter< ::QXmlStreamReader >
{
};

template<>
struct Converter< ::QXmlStreamReader > : ObjectTypeReferenceConverter< ::QXmlStreamReader >
{
};

template<>
struct Converter< ::QXmlStreamEntityResolver* > : ObjectTypeConverter< ::QXmlStreamEntityResolver >
{
};

template<>
struct Converter< ::QXmlStreamEntityResolver > : ObjectTypeReferenceConverter< ::QXmlStreamEntityResolver >
{
};

template<>
struct Converter< ::QXmlStreamEntityDeclaration > : ValueTypeConverter< ::QXmlStreamEntityDeclaration >
{
};

template<>
struct Converter< ::QXmlStreamNotationDeclaration > : ValueTypeConverter< ::QXmlStreamNotationDeclaration >
{
};

template<>
struct Converter< ::QXmlStreamNamespaceDeclaration > : ValueTypeConverter< ::QXmlStreamNamespaceDeclaration >
{
};

template<>
struct Converter< ::QXmlStreamAttributes > : ValueTypeConverter< ::QXmlStreamAttributes >
{
};

template<>
struct Converter< ::QXmlStreamAttribute > : ValueTypeConverter< ::QXmlStreamAttribute >
{
};

template<>
struct Converter< ::QFactoryInterface* > : ObjectTypeConverter< ::QFactoryInterface >
{
};

template<>
struct Converter< ::QFactoryInterface > : ObjectTypeReferenceConverter< ::QFactoryInterface >
{
};

template<>
struct Converter< ::QRegExp::PatternSyntax > : EnumConverter< ::QRegExp::PatternSyntax >
{
};

template<>
struct Converter< ::QRegExp::CaretMode > : EnumConverter< ::QRegExp::CaretMode >
{
};

template<>
struct Converter< ::QRegExp > : ValueTypeConverter< ::QRegExp >
{
};

template<>
struct Converter< ::QTextDecoder* > : ObjectTypeConverter< ::QTextDecoder >
{
};

template<>
struct Converter< ::QTextDecoder > : ObjectTypeReferenceConverter< ::QTextDecoder >
{
};

template<>
struct Converter< ::QTextEncoder* > : ObjectTypeConverter< ::QTextEncoder >
{
};

template<>
struct Converter< ::QTextEncoder > : ObjectTypeReferenceConverter< ::QTextEncoder >
{
};

template<>
struct Converter< ::QTextCodec::ConversionFlag > : EnumConverter< ::QTextCodec::ConversionFlag >
{
};
template<>
struct Converter< ::QFlags<QTextCodec::ConversionFlag> > : QFlagsConverter< ::QFlags<QTextCodec::ConversionFlag> >
{
};

template<>
struct Converter< ::QTextCodec* > : ObjectTypeConverter< ::QTextCodec >
{
};

template<>
struct Converter< ::QTextCodec > : ObjectTypeReferenceConverter< ::QTextCodec >
{
};

template<>
struct Converter< ::QTextCodec::ConverterState* > : ObjectTypeConverter< ::QTextCodec::ConverterState >
{
};

template<>
struct Converter< ::QTextCodec::ConverterState > : ObjectTypeReferenceConverter< ::QTextCodec::ConverterState >
{
};

template<>
struct Converter< ::QSystemSemaphore::AccessMode > : EnumConverter< ::QSystemSemaphore::AccessMode >
{
};

template<>
struct Converter< ::QSystemSemaphore::SystemSemaphoreError > : EnumConverter< ::QSystemSemaphore::SystemSemaphoreError >
{
};

template<>
struct Converter< ::QSystemSemaphore* > : ObjectTypeConverter< ::QSystemSemaphore >
{
};

template<>
struct Converter< ::QSystemSemaphore > : ObjectTypeReferenceConverter< ::QSystemSemaphore >
{
};

template<>
struct Converter< ::QMetaClassInfo > : ValueTypeConverter< ::QMetaClassInfo >
{
};

template<>
struct Converter< ::QMetaProperty > : ValueTypeConverter< ::QMetaProperty >
{
};

template<>
struct Converter< ::QMetaEnum > : ValueTypeConverter< ::QMetaEnum >
{
};

template<>
struct Converter< ::QEvent::Type > : EnumConverter< ::QEvent::Type >
{
};

template<>
struct Converter< ::QEvent* > : ObjectTypeConverter< ::QEvent >
{
};

template<>
struct Converter< ::QEvent > : ObjectTypeReferenceConverter< ::QEvent >
{
};

template<>
struct Converter< ::QDynamicPropertyChangeEvent* > : ObjectTypeConverter< ::QDynamicPropertyChangeEvent >
{
};

template<>
struct Converter< ::QDynamicPropertyChangeEvent > : ObjectTypeReferenceConverter< ::QDynamicPropertyChangeEvent >
{
};

template<>
struct Converter< ::QChildEvent* > : ObjectTypeConverter< ::QChildEvent >
{
};

template<>
struct Converter< ::QChildEvent > : ObjectTypeReferenceConverter< ::QChildEvent >
{
};

template<>
struct Converter< ::QTimerEvent* > : ObjectTypeConverter< ::QTimerEvent >
{
};

template<>
struct Converter< ::QTimerEvent > : ObjectTypeReferenceConverter< ::QTimerEvent >
{
};

template<>
struct Converter< ::QBasicTimer > : ValueTypeConverter< ::QBasicTimer >
{
};

template<>
struct Converter< ::QPersistentModelIndex > : ValueTypeConverter< ::QPersistentModelIndex >
{
    static ::QPersistentModelIndex toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QModelIndex > : ValueTypeConverter< ::QModelIndex >
{
};

template<>
struct Converter< ::QDateTime > : ValueTypeConverter< ::QDateTime >
{
};

template<>
struct Converter< ::QTime > : ValueTypeConverter< ::QTime >
{
};

template<>
struct Converter< ::QDate::MonthNameType > : EnumConverter< ::QDate::MonthNameType >
{
};

template<>
struct Converter< ::QDate > : ValueTypeConverter< ::QDate >
{
};

template<>
struct Converter< ::QDataStream::FloatingPointPrecision > : EnumConverter< ::QDataStream::FloatingPointPrecision >
{
};

template<>
struct Converter< ::QDataStream::Version > : EnumConverter< ::QDataStream::Version >
{
};

template<>
struct Converter< ::QDataStream::Status > : EnumConverter< ::QDataStream::Status >
{
};

template<>
struct Converter< ::QDataStream* > : ObjectTypeConverter< ::QDataStream >
{
};

template<>
struct Converter< ::QDataStream > : ObjectTypeReferenceConverter< ::QDataStream >
{
};

template<>
struct Converter< ::QEasingCurve::Type > : EnumConverter< ::QEasingCurve::Type >
{
};

template<>
struct Converter< ::QEasingCurve > : ValueTypeConverter< ::QEasingCurve >
{
    static ::QEasingCurve toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QObject* > : ObjectTypeConverter< ::QObject >
{
};

template<>
struct Converter< ::QObject > : ObjectTypeReferenceConverter< ::QObject >
{
};

template<>
struct Converter< ::QAbstractTransition* > : ObjectTypeConverter< ::QAbstractTransition >
{
};

template<>
struct Converter< ::QAbstractTransition > : ObjectTypeReferenceConverter< ::QAbstractTransition >
{
};

template<>
struct Converter< ::QSignalTransition* > : ObjectTypeConverter< ::QSignalTransition >
{
};

template<>
struct Converter< ::QSignalTransition > : ObjectTypeReferenceConverter< ::QSignalTransition >
{
};

template<>
struct Converter< ::QEventTransition* > : ObjectTypeConverter< ::QEventTransition >
{
};

template<>
struct Converter< ::QEventTransition > : ObjectTypeReferenceConverter< ::QEventTransition >
{
};

template<>
struct Converter< ::QAbstractState* > : ObjectTypeConverter< ::QAbstractState >
{
};

template<>
struct Converter< ::QAbstractState > : ObjectTypeReferenceConverter< ::QAbstractState >
{
};

template<>
struct Converter< ::QState::ChildMode > : EnumConverter< ::QState::ChildMode >
{
};

template<>
struct Converter< ::QState* > : ObjectTypeConverter< ::QState >
{
};

template<>
struct Converter< ::QState > : ObjectTypeReferenceConverter< ::QState >
{
};

template<>
struct Converter< ::QStateMachine::Error > : EnumConverter< ::QStateMachine::Error >
{
};

template<>
struct Converter< ::QStateMachine::EventPriority > : EnumConverter< ::QStateMachine::EventPriority >
{
};

template<>
struct Converter< ::QStateMachine::RestorePolicy > : EnumConverter< ::QStateMachine::RestorePolicy >
{
};

template<>
struct Converter< ::QStateMachine* > : ObjectTypeConverter< ::QStateMachine >
{
};

template<>
struct Converter< ::QStateMachine > : ObjectTypeReferenceConverter< ::QStateMachine >
{
};

template <>
struct SbkTypeInfo<QStateMachine::WrappedEvent >
{
    static const bool isCppWrapper = true;
};
template<>
struct Converter< ::QStateMachine::WrappedEvent > : ValueTypeConverter< ::QStateMachine::WrappedEvent >
{
};

template <>
struct SbkTypeInfo<QStateMachine::SignalEvent >
{
    static const bool isCppWrapper = true;
};
template<>
struct Converter< ::QStateMachine::SignalEvent > : ValueTypeConverter< ::QStateMachine::SignalEvent >
{
};

template<>
struct Converter< ::QHistoryState::HistoryType > : EnumConverter< ::QHistoryState::HistoryType >
{
};

template<>
struct Converter< ::QHistoryState* > : ObjectTypeConverter< ::QHistoryState >
{
};

template<>
struct Converter< ::QHistoryState > : ObjectTypeReferenceConverter< ::QHistoryState >
{
};

template<>
struct Converter< ::QFinalState* > : ObjectTypeConverter< ::QFinalState >
{
};

template<>
struct Converter< ::QFinalState > : ObjectTypeReferenceConverter< ::QFinalState >
{
};

template<>
struct Converter< ::QThreadPool* > : ObjectTypeConverter< ::QThreadPool >
{
};

template<>
struct Converter< ::QThreadPool > : ObjectTypeReferenceConverter< ::QThreadPool >
{
};

template<>
struct Converter< ::QThread::Priority > : EnumConverter< ::QThread::Priority >
{
};

template<>
struct Converter< ::QThread* > : ObjectTypeConverter< ::QThread >
{
};

template<>
struct Converter< ::QThread > : ObjectTypeReferenceConverter< ::QThread >
{
};

template<>
struct Converter< ::QAbstractItemModel* > : ObjectTypeConverter< ::QAbstractItemModel >
{
};

template<>
struct Converter< ::QAbstractItemModel > : ObjectTypeReferenceConverter< ::QAbstractItemModel >
{
};

template<>
struct Converter< ::QAbstractListModel* > : ObjectTypeConverter< ::QAbstractListModel >
{
};

template<>
struct Converter< ::QAbstractListModel > : ObjectTypeReferenceConverter< ::QAbstractListModel >
{
};

template<>
struct Converter< ::QAbstractTableModel* > : ObjectTypeConverter< ::QAbstractTableModel >
{
};

template<>
struct Converter< ::QAbstractTableModel > : ObjectTypeReferenceConverter< ::QAbstractTableModel >
{
};

template<>
struct Converter< ::QSettings::Format > : EnumConverter< ::QSettings::Format >
{
};

template<>
struct Converter< ::QSettings::Status > : EnumConverter< ::QSettings::Status >
{
};

template<>
struct Converter< ::QSettings::Scope > : EnumConverter< ::QSettings::Scope >
{
};

template<>
struct Converter< ::QSettings* > : ObjectTypeConverter< ::QSettings >
{
};

template<>
struct Converter< ::QSettings > : ObjectTypeReferenceConverter< ::QSettings >
{
};

template<>
struct Converter< ::QAbstractEventDispatcher* > : ObjectTypeConverter< ::QAbstractEventDispatcher >
{
};

template<>
struct Converter< ::QAbstractEventDispatcher > : ObjectTypeReferenceConverter< ::QAbstractEventDispatcher >
{
};

template<>
struct Converter< ::QPluginLoader* > : ObjectTypeConverter< ::QPluginLoader >
{
};

template<>
struct Converter< ::QPluginLoader > : ObjectTypeReferenceConverter< ::QPluginLoader >
{
};

template<>
struct Converter< ::QEventLoop::ProcessEventsFlag > : EnumConverter< ::QEventLoop::ProcessEventsFlag >
{
};
template<>
struct Converter< ::QFlags<QEventLoop::ProcessEventsFlag> > : QFlagsConverter< ::QFlags<QEventLoop::ProcessEventsFlag> >
{
};

template<>
struct Converter< ::QEventLoop* > : ObjectTypeConverter< ::QEventLoop >
{
};

template<>
struct Converter< ::QEventLoop > : ObjectTypeReferenceConverter< ::QEventLoop >
{
};

template<>
struct Converter< ::QCoreApplication::Encoding > : EnumConverter< ::QCoreApplication::Encoding >
{
};

template<>
struct Converter< ::QCoreApplication* > : ObjectTypeConverter< ::QCoreApplication >
{
};

template<>
struct Converter< ::QCoreApplication > : ObjectTypeReferenceConverter< ::QCoreApplication >
{
};

template<>
struct Converter< ::QFileSystemWatcher* > : ObjectTypeConverter< ::QFileSystemWatcher >
{
};

template<>
struct Converter< ::QFileSystemWatcher > : ObjectTypeReferenceConverter< ::QFileSystemWatcher >
{
};

template<>
struct Converter< ::QIODevice::OpenModeFlag > : EnumConverter< ::QIODevice::OpenModeFlag >
{
};
template<>
struct Converter< ::QFlags<QIODevice::OpenModeFlag> > : QFlagsConverter< ::QFlags<QIODevice::OpenModeFlag> >
{
};

template<>
struct Converter< ::QIODevice* > : ObjectTypeConverter< ::QIODevice >
{
};

template<>
struct Converter< ::QIODevice > : ObjectTypeReferenceConverter< ::QIODevice >
{
};

template<>
struct Converter< ::QFile::FileError > : EnumConverter< ::QFile::FileError >
{
};

template<>
struct Converter< ::QFile::MemoryMapFlags > : EnumConverter< ::QFile::MemoryMapFlags >
{
};

template<>
struct Converter< ::QFile::Permission > : EnumConverter< ::QFile::Permission >
{
};
template<>
struct Converter< ::QFlags<QFile::Permission> > : QFlagsConverter< ::QFlags<QFile::Permission> >
{
};

template<>
struct Converter< ::QFile* > : ObjectTypeConverter< ::QFile >
{
};

template<>
struct Converter< ::QFile > : ObjectTypeReferenceConverter< ::QFile >
{
};

template<>
struct Converter< ::QTemporaryFile* > : ObjectTypeConverter< ::QTemporaryFile >
{
};

template<>
struct Converter< ::QTemporaryFile > : ObjectTypeReferenceConverter< ::QTemporaryFile >
{
};

template<>
struct Converter< ::QTextStream::RealNumberNotation > : EnumConverter< ::QTextStream::RealNumberNotation >
{
};

template<>
struct Converter< ::QTextStream::NumberFlag > : EnumConverter< ::QTextStream::NumberFlag >
{
};
template<>
struct Converter< ::QFlags<QTextStream::NumberFlag> > : QFlagsConverter< ::QFlags<QTextStream::NumberFlag> >
{
};

template<>
struct Converter< ::QTextStream::FieldAlignment > : EnumConverter< ::QTextStream::FieldAlignment >
{
};

template<>
struct Converter< ::QTextStream::Status > : EnumConverter< ::QTextStream::Status >
{
};

template<>
struct Converter< ::QTextStream* > : ObjectTypeConverter< ::QTextStream >
{
};

template<>
struct Converter< ::QTextStream > : ObjectTypeReferenceConverter< ::QTextStream >
{
};

template<>
struct Converter< ::QProcess::ProcessError > : EnumConverter< ::QProcess::ProcessError >
{
};

template<>
struct Converter< ::QProcess::ProcessChannelMode > : EnumConverter< ::QProcess::ProcessChannelMode >
{
};

template<>
struct Converter< ::QProcess::ProcessChannel > : EnumConverter< ::QProcess::ProcessChannel >
{
};

template<>
struct Converter< ::QProcess::ProcessState > : EnumConverter< ::QProcess::ProcessState >
{
};

template<>
struct Converter< ::QProcess::ExitStatus > : EnumConverter< ::QProcess::ExitStatus >
{
};

template<>
struct Converter< ::QProcess* > : ObjectTypeConverter< ::QProcess >
{
};

template<>
struct Converter< ::QProcess > : ObjectTypeReferenceConverter< ::QProcess >
{
};

template<>
struct Converter< ::QBuffer* > : ObjectTypeConverter< ::QBuffer >
{
};

template<>
struct Converter< ::QBuffer > : ObjectTypeReferenceConverter< ::QBuffer >
{
};

template<>
struct Converter< ::QAbstractAnimation::Direction > : EnumConverter< ::QAbstractAnimation::Direction >
{
};

template<>
struct Converter< ::QAbstractAnimation::DeletionPolicy > : EnumConverter< ::QAbstractAnimation::DeletionPolicy >
{
};

template<>
struct Converter< ::QAbstractAnimation::State > : EnumConverter< ::QAbstractAnimation::State >
{
};

template<>
struct Converter< ::QAbstractAnimation* > : ObjectTypeConverter< ::QAbstractAnimation >
{
};

template<>
struct Converter< ::QAbstractAnimation > : ObjectTypeReferenceConverter< ::QAbstractAnimation >
{
};

template<>
struct Converter< ::QVariantAnimation* > : ObjectTypeConverter< ::QVariantAnimation >
{
};

template<>
struct Converter< ::QVariantAnimation > : ObjectTypeReferenceConverter< ::QVariantAnimation >
{
};

template<>
struct Converter< ::QPropertyAnimation* > : ObjectTypeConverter< ::QPropertyAnimation >
{
};

template<>
struct Converter< ::QPropertyAnimation > : ObjectTypeReferenceConverter< ::QPropertyAnimation >
{
};

template<>
struct Converter< ::QPauseAnimation* > : ObjectTypeConverter< ::QPauseAnimation >
{
};

template<>
struct Converter< ::QPauseAnimation > : ObjectTypeReferenceConverter< ::QPauseAnimation >
{
};

template<>
struct Converter< ::QAnimationGroup* > : ObjectTypeConverter< ::QAnimationGroup >
{
};

template<>
struct Converter< ::QAnimationGroup > : ObjectTypeReferenceConverter< ::QAnimationGroup >
{
};

template<>
struct Converter< ::QSequentialAnimationGroup* > : ObjectTypeConverter< ::QSequentialAnimationGroup >
{
};

template<>
struct Converter< ::QSequentialAnimationGroup > : ObjectTypeReferenceConverter< ::QSequentialAnimationGroup >
{
};

template<>
struct Converter< ::QParallelAnimationGroup* > : ObjectTypeConverter< ::QParallelAnimationGroup >
{
};

template<>
struct Converter< ::QParallelAnimationGroup > : ObjectTypeReferenceConverter< ::QParallelAnimationGroup >
{
};

template<>
struct Converter< ::QTranslator* > : ObjectTypeConverter< ::QTranslator >
{
};

template<>
struct Converter< ::QTranslator > : ObjectTypeReferenceConverter< ::QTranslator >
{
};

template<>
struct Converter< ::QTimer* > : ObjectTypeConverter< ::QTimer >
{
};

template<>
struct Converter< ::QTimer > : ObjectTypeReferenceConverter< ::QTimer >
{
};

template<>
struct Converter< ::QTimeLine::Direction > : EnumConverter< ::QTimeLine::Direction >
{
};

template<>
struct Converter< ::QTimeLine::CurveShape > : EnumConverter< ::QTimeLine::CurveShape >
{
};

template<>
struct Converter< ::QTimeLine::State > : EnumConverter< ::QTimeLine::State >
{
};

template<>
struct Converter< ::QTimeLine* > : ObjectTypeConverter< ::QTimeLine >
{
};

template<>
struct Converter< ::QTimeLine > : ObjectTypeReferenceConverter< ::QTimeLine >
{
};

template<>
struct Converter< ::QSocketNotifier::Type > : EnumConverter< ::QSocketNotifier::Type >
{
};

template<>
struct Converter< ::QSocketNotifier* > : ObjectTypeConverter< ::QSocketNotifier >
{
};

template<>
struct Converter< ::QSocketNotifier > : ObjectTypeReferenceConverter< ::QSocketNotifier >
{
};

template<>
struct Converter< ::QSignalMapper* > : ObjectTypeConverter< ::QSignalMapper >
{
};

template<>
struct Converter< ::QSignalMapper > : ObjectTypeReferenceConverter< ::QSignalMapper >
{
};

template<>
struct Converter< ::QMimeData* > : ObjectTypeConverter< ::QMimeData >
{
};

template<>
struct Converter< ::QMimeData > : ObjectTypeReferenceConverter< ::QMimeData >
{
};

template<>
struct Converter< ::QLibraryInfo::LibraryLocation > : EnumConverter< ::QLibraryInfo::LibraryLocation >
{
};

template<>
struct Converter< ::QLibraryInfo* > : ObjectTypeConverter< ::QLibraryInfo >
{
};

template<>
struct Converter< ::QLibraryInfo > : ObjectTypeReferenceConverter< ::QLibraryInfo >
{
};

template<>
struct Converter< ::QByteArray > : ValueTypeConverter< ::QByteArray >
{
    static ::QByteArray toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QUrl::ParsingMode > : EnumConverter< ::QUrl::ParsingMode >
{
};

template<>
struct Converter< ::QUrl::FormattingOption > : EnumConverter< ::QUrl::FormattingOption >
{
};
template<>
struct Converter< ::QFlags<QUrl::FormattingOption> > : QFlagsConverter< ::QFlags<QUrl::FormattingOption> >
{
};

template<>
struct Converter< ::QUrl > : ValueTypeConverter< ::QUrl >
{
    static ::QUrl toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QGenericArgument > : ValueTypeConverter< ::QGenericArgument >
{
};

template<>
struct Converter< ::QMetaMethod::Access > : EnumConverter< ::QMetaMethod::Access >
{
};

template<>
struct Converter< ::QMetaMethod::MethodType > : EnumConverter< ::QMetaMethod::MethodType >
{
};

template<>
struct Converter< ::QMetaMethod > : ValueTypeConverter< ::QMetaMethod >
{
};

template<>
struct Converter< ::QMetaObject::Call > : EnumConverter< ::QMetaObject::Call >
{
};

template<>
struct Converter< ::QMetaObject* > : ObjectTypeConverter< ::QMetaObject >
{
};

template<>
struct Converter< ::QMetaObject > : ObjectTypeReferenceConverter< ::QMetaObject >
{
};

template<>
struct Converter< ::QGenericReturnArgument > : ValueTypeConverter< ::QGenericReturnArgument >
{
};

template<>
struct Converter< ::QSysInfo::Endian > : EnumConverter< ::QSysInfo::Endian >
{
};

template<>
struct Converter< ::QSysInfo::Sizes > : EnumConverter< ::QSysInfo::Sizes >
{
};

template<>
struct Converter< ::QSysInfo* > : ObjectTypeConverter< ::QSysInfo >
{
};

template<>
struct Converter< ::QSysInfo > : ObjectTypeReferenceConverter< ::QSysInfo >
{
};

} // namespace Shiboken

// User defined converters --------------------------------------------
// Conversion rule for: QList
namespace Shiboken {
template<typename T>
struct Converter<QList<T> > : StdListConverter<QList<T> > {};
}
// Conversion rule for: QString
namespace Shiboken {

template<>
inline PyTypeObject* SbkType<QString>()
{
    return &PyUnicode_Type;
}

template<>
struct Converter<QString>
{
    static bool checkType(PyObject* pyObj)
    {
        return PyString_Check(pyObj) || PyUnicode_Check(pyObj);
    }

    static bool isConvertible(PyObject* pyObj)
    {
        return PyString_Check(pyObj)
                || PyUnicode_Check(pyObj)
                || pyObj == Py_None;
    }

    static QString toCpp(PyObject* pyObj)
    {
        if (PyUnicode_Check(pyObj)) {
            Py_UNICODE* unicode = PyUnicode_AS_UNICODE(pyObj);
    #if defined(Py_UNICODE_WIDE)
            // cast as Py_UNICODE can be a different type
            return QString::fromUcs4(reinterpret_cast<const uint*>(unicode));
    #else
            return QString::fromUtf16(unicode, PyUnicode_GET_SIZE(pyObj));
    #endif
        } else if (PyString_Check(pyObj)) {
            return QString(Converter<const char * >::toCpp(pyObj));
        }
        return QString();
    }

    static PyObject* toPython(void* cppObj) { return toPython(*reinterpret_cast<QString*>(cppObj)); }
    static PyObject* toPython(const QString& cppObj)
    {
        const int N = cppObj.length();
        wchar_t* str = new wchar_t[N];
        cppObj.toWCharArray(str);
        PyObject* pyObj = PyUnicode_FromWideChar(str, N);
        delete[] str;
        return pyObj;
    }
};
}
// Conversion rule for: QMap
namespace Shiboken {
template<typename KT, typename VT>
struct Converter<QMap<KT, VT> > : QtDictConverter<QMap<KT, VT> > {
};
}
// Conversion rule for: QStack
namespace Shiboken {
template<typename T>
struct Converter<QStack<T> > : StdListConverter<QStack<T> > {};
}
// Conversion rule for: QMultiMap
namespace Shiboken {
template<typename KT, typename VT>
struct Converter<QMultiMap<KT, VT> > : QtMultiMapConverter<QMap<KT, VT> > {
};
}
// Conversion rule for: QVariant
namespace Shiboken {

template<>
struct Converter<QVariant>
{
    static bool checkType(PyObject* pyObj)
    {
        return false; // lets avoid the chaos
    }

    // all types are convertible to QVariant
    static bool isConvertible(PyObject* pyObj)
    {
        return true;
    }

    static QByteArray resolveMetaType(PyTypeObject* type, int &typeId)
    {
        if (PyObject_TypeCheck(type, &SbkObjectType_Type)) {
            SbkObjectType* sbkType = reinterpret_cast<SbkObjectType*>(type);
            QByteArray typeName(Shiboken::ObjectType::getOriginalName(sbkType));
            bool valueType = !typeName.endsWith("*");

            // Do not convert user type of value
            if (valueType && Shiboken::ObjectType::isUserType(type))
                return QByteArray();

            int obTypeId = QMetaType::type(typeName);
            if (obTypeId) {
                typeId = obTypeId;
                return QByteArray(typeName);
            }

            // Do not resolve types to value type
            if (valueType)
                return QByteArray();

            // find in base types
            if (type->tp_base) {
                return resolveMetaType(type->tp_base, typeId);
            } else if (type->tp_bases) {
                int size = PyTuple_GET_SIZE(type->tp_bases);
                for(int i=0; i < size; i++){
                    QByteArray derivedName = resolveMetaType(reinterpret_cast<PyTypeObject*>(PyTuple_GET_ITEM(type->tp_bases, i)), typeId);
                    if (!derivedName.isEmpty())
                        return derivedName;
                }
            }
        }
        typeId = 0;
        return QByteArray();
    }

    static QVariant toCpp(PyObject* pyObj)
    {
        using namespace Shiboken;

        // Primitive types
        if (Converter<bool>::checkType(pyObj)) {
            // QVariant(bool)
            return QVariant(Converter<bool>::toCpp(pyObj));
        } else if (pyObj == Py_None) {
            // QVariant()
            return QVariant();
        } else if (Converter<QString>::checkType(pyObj)) {
            // QVariant(const char*)
            return QVariant(Converter<QString>::toCpp(pyObj));
        } else if (Converter<QByteArray>::checkType(pyObj)) {
            // QVariant(QByteArray)
            return QVariant(Converter<QByteArray>::toCpp(pyObj));
        } else if (PyFloat_CheckExact(pyObj)) {
            // QVariant(double)
            return QVariant(Converter<double>::toCpp(pyObj));
        } else if (PyInt_Check(pyObj)) {
            // QVariant(int)
            return QVariant(Converter<int>::toCpp(pyObj));
        } else if (PyLong_CheckExact(pyObj)) {
            // QVariant(qlonglong)
            return QVariant(Converter<qlonglong>::toCpp(pyObj));
        } else if (Shiboken::isShibokenEnum(pyObj)) {
            // QVariant(enum)
            return QVariant(Converter<int>::toCpp(pyObj));
        } else if (PyDict_Check(pyObj)) {
            return convertToVariantMap(pyObj);
        } else if (PySequence_Check(pyObj)) {
            return convertToVariantList(pyObj);
        } else {
            // a class supported by QVariant?
            if (Shiboken::Object::checkType(pyObj)) {
                SbkObjectType* objType = reinterpret_cast<SbkObjectType*>(pyObj->ob_type);
                int typeCode = 0;
                QByteArray typeName = resolveMetaType(reinterpret_cast<PyTypeObject*>(objType), typeCode);
                if (typeCode) {
                    Shiboken::TypeResolver* tr = Shiboken::TypeResolver::get(typeName);
                    void* data = 0;
                    data = tr->toCpp(pyObj, &data, true);
                    if (typeName.endsWith("*")) {
                        QVariant var(typeCode, &data);
                        tr->deleteObject(data);
                        return var;
                    } else {
                        QVariant var(typeCode, data);
                        tr->deleteObject(data);
                        return var;
                    }
                }
            }
            // Is a shiboken type not known by Qt
            return QVariant::fromValue<PySide::PyObjectWrapper>(pyObj);
        }
    }

    static PyObject* toPython(void* cppObj)
    {
        return toPython(*reinterpret_cast<QVariant*>(cppObj));
    }

    static PyObject* toPython(const QVariant& cppObj)
    {
        if (cppObj.isValid()) {
            if (qstrcmp(cppObj.typeName(), "QVariantList") == 0)
                return Converter<QList<QVariant> >::toPython(cppObj.value<QVariantList>());

            if (qstrcmp(cppObj.typeName(), "QStringList") == 0)
                return Converter<QList<QString> >::toPython(cppObj.value<QStringList>());

            if (qstrcmp(cppObj.typeName(), "QVariantMap") == 0)
                return Converter<QMap<QString, QVariant> >::toPython(cppObj.value<QVariantMap>());

            Shiboken::TypeResolver* tr = Shiboken::TypeResolver::get(cppObj.typeName());
            if (tr)
                return tr->toPython(const_cast<void*>(cppObj.data()));
        }
        Py_RETURN_NONE;
    }

    static QVariant convertToValueList(PyObject* list)
    {
        if (PySequence_Size(list) < 1)
            return QVariant();

        Shiboken::AutoDecRef element(PySequence_GetItem(list, 0));
        int typeId = 0;
        QByteArray typeName = resolveMetaType(element.cast<PyTypeObject*>(), typeId);
        if (!typeName.isEmpty()) {
            QByteArray listTypeName = QByteArray("QList<"+typeName+">");
            typeId = QMetaType::type(listTypeName);
            if (typeId > 0) {
                Shiboken::TypeResolver* tr = Shiboken::TypeResolver::get(listTypeName);
                if (!tr) {
                    qWarning() << "TypeResolver for :" << listTypeName << "not registered.";
                    return QVariant();
                } else {
                    void *data = 0;
                    data = tr->toCpp(list, &data, true);
                    QVariant var(typeId, data);
                    tr->deleteObject(data);
                    return var;
                }
            } else {
                return QVariant();
            }
        }

        return QVariant();
    }

    static QVariant convertToVariantMap(PyObject* map)
    {
        PyObject *key, *value;
        Py_ssize_t pos = 0;
        AutoDecRef keys(PyDict_Keys(map));
        bool keysIsString = isStringList(keys);
        if (keysIsString) {
            QMap<QString, QVariant> ret;
            while (PyDict_Next(map, &pos, &key, &value))
                ret.insert(Converter<QString>::toCpp(key), toCpp(value));
            return QVariant(ret);
        } else {
            return toCpp(map);
        }
    }

    static bool isStringList(PyObject *list)
    {
        bool allString = true;
        AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
        Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
        for(int i=0; i < size; i++) {
            PyObject* item = PySequence_Fast_GET_ITEM(fast.object(), i);
            if (!Converter<QString>::checkType(item)) {
                allString = false;
                break;
            }
        }
        return allString;
    }

    static QVariant convertToVariantList(PyObject* list)
    {
        bool allString = isStringList(list);
        if (allString) {
            QStringList lst = Converter<QList<QString> >::toCpp(list);
            return QVariant(lst);
        } else {
            QVariant valueList = convertToValueList(list);
            if (valueList.isValid())
                return valueList;
            QList<QVariant> lst;
            AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
            Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
            for(int i=0; i < size; i++) {
                PyObject* item = PySequence_Fast_GET_ITEM(fast.object(), i);
                lst.append(toCpp(item));
            }
            return QVariant(lst);
        }
        Q_ASSERT(false);
    }
};
}
// Conversion rule for: QVector
namespace Shiboken {
template<typename T>
struct Converter<QVector<T> > : StdListConverter<QVector<T> > {};
}
// Conversion rule for: QBool
namespace Shiboken {
template <>
struct Converter<QBool> : public ValueTypeConverter<QBool>
{
    using ValueTypeConverter<QBool>::toPython;

    static PyObject* toPython(const QBool& cppobj)
    {
        return PyBool_FromLong((bool) cppobj);
    }
    static QBool toCpp(PyObject* pyobj)
    {
        return QBool(pyobj == Py_True);
    }
};
}
// Conversion rule for: QVariant::Type
namespace Shiboken {

template<>
struct Converter<QVariant::Type>
{
    static bool checkType(PyObject* pyObj)
    {
        return pyObj == Py_None || PyType_Check(pyObj) || Converter<QString>::checkType(pyObj);
    }

    static bool isConvertible(PyObject* pyObj)
    {
        return checkType(pyObj);
    }

    static QVariant::Type toCpp(PyObject* pyObj)
    {
        const char* typeName = 0;
        if (pyObj == Py_None)
            return QVariant::Invalid;

        if (pyObj == reinterpret_cast<PyObject*>(&PyString_Type) || pyObj == reinterpret_cast<PyObject*>(&PyUnicode_Type))
            typeName = "QString";
        else if (pyObj == reinterpret_cast<PyObject*>(&PyFloat_Type))
            typeName = "double"; // float is a UserType in QVariant.
        else if (pyObj == reinterpret_cast<PyObject*>(&PyLong_Type))
            typeName = "int"; // long is a UserType in QVariant.
        else if (PyType_Check(pyObj)) {
            if (pyObj->ob_type == &SbkObjectType_Type)
                typeName = Shiboken::ObjectType::getOriginalName(reinterpret_cast<SbkObjectType*>(pyObj));
            else
                typeName = reinterpret_cast<PyTypeObject*>(pyObj)->tp_name;
        }
        else if (PyString_Check(pyObj))
            typeName = PyString_AS_STRING(pyObj);
        else if (PyUnicode_Check(pyObj))
            typeName = PyString_AsString(pyObj);
        else if (PyDict_Check(pyObj) && checkAllStringKeys(pyObj))
            typeName = "QVariantMap";
        else if (PySequence_Check(pyObj))
            if (isStringList(pyObj))
                typeName = "QStringList";
            else
                typeName = "QVariantList";
        else
            Q_ASSERT(false);

        return QVariant::nameToType(typeName);
    }

    static PyObject* toPython(void* cppObj) { return toPython(*reinterpret_cast<QVariant::Type*>(cppObj)); }
    static PyObject* toPython(const QVariant::Type& cppObj)
    {
        const char* typeName = QVariant::typeToName(cppObj);
        PyObject* pyObj;
        if (!typeName) {
            pyObj = Py_None;
        } else {
            Shiboken::TypeResolver* tr = Shiboken::TypeResolver::get(typeName);
            pyObj = tr ? reinterpret_cast<PyObject*>(tr->pythonType()) : Py_None;
        }
        Py_INCREF(pyObj);
        return pyObj;
    }

    static bool isStringList(PyObject* list)
    {
        bool allString = true;
        AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
        Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
        for(int i=0; i < size; i++) {
            PyObject* item = PySequence_Fast_GET_ITEM(fast.object(), i);
            if (!Converter<QString>::checkType(item)) {
                allString = false;
                break;
            }
        }
        return allString;
    }

    static bool checkAllStringKeys(PyObject* dict)
    {
        AutoDecRef keys(PyDict_Keys(dict));
        return isStringList(keys);
    }
};
}
// Conversion rule for: QPair
namespace Shiboken {
template<typename FT, typename ST>
struct Converter<QPair<FT, ST> > : StdPairConverter<QPair<FT, ST> > {};
}
// Conversion rule for: QHash
namespace Shiboken {
template<typename KT, typename VT>
struct Converter<QHash<KT, VT> > : QtDictConverter<QHash<KT, VT> > {};
}
// Conversion rule for: QSet
namespace Shiboken {
template<typename T>
struct Converter<QSet<T> > : QSequenceConverter<QSet<T> > {};
}
// Conversion rule for: QStringRef
namespace Shiboken {

template<>
struct Converter<QStringRef> : public Converter<QString>
{
    static PyObject* toPython(void* cppObj) { return toPython(*reinterpret_cast<QStringRef*>(cppObj)); }

    static PyObject* toPython(const QStringRef& cppObj)
    {
        return Converter<QString>::toPython(cppObj.toString());
    }

    static QStringRef toCpp(PyObject* pyObj)
    {
        return QStringRef();
    }
};
}
// Conversion rule for: QStringList
namespace Shiboken
{
template<>
struct Converter<QStringList> : StdListConverter<QStringList> {};
}
// Conversion rule for: QChar
namespace Shiboken {

template<>
struct Converter<QChar>
{
    static bool checkType(PyObject* pyObj)
    {
        return PyString_Check(pyObj) && (PyString_Size(pyObj) == 1);
    }

    static bool isConvertible(PyObject* pyObj)
    {
        return (PyString_Check(pyObj) && (PyString_Size(pyObj) == 1))
               || pyObj == Py_None
               || PyInt_Check(pyObj);
    }

    static QChar toCpp(PyObject* pyObj)
    {
        if (PyString_Check(pyObj) && PyString_Size(pyObj) == 1)
            return QChar(Shiboken::Converter<char >::toCpp(pyObj));
        else if (PyInt_Check(pyObj))
            return QChar(Shiboken::Converter<int >::toCpp(pyObj));
        return QChar();
    }

    static PyObject* toPython(void* cppObj) { return toPython(*reinterpret_cast<QChar*>(cppObj)); }
    static PyObject* toPython(const QChar& cppObj)
    {
        wchar_t c = (wchar_t)cppObj.unicode();
        PyObject* pyObj = PyUnicode_FromWideChar(&c, 1);
        return pyObj;
    }
};
}
// Generated converters implemantations -------------------------------

inline bool Shiboken::Converter< ::QRectF >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QRectF >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QRectF >());
    return Shiboken::Converter< ::QRect >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QRectF Shiboken::Converter< ::QRectF >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QRectF >()))
        return *Shiboken::Converter< QRectF* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QRect >::checkType(pyobj))
        return QRectF(Shiboken::Converter< ::QRect >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QRectF >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QSizeF >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QSizeF >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QSizeF >());
    return Shiboken::Converter< ::QSize >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QSizeF Shiboken::Converter< ::QSizeF >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QSizeF >()))
        return *Shiboken::Converter< QSizeF* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QSize >::checkType(pyobj))
        return QSizeF(Shiboken::Converter< ::QSize >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QSizeF >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QLineF >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QLineF >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QLineF >());
    return Shiboken::Converter< ::QLine >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QLineF Shiboken::Converter< ::QLineF >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QLineF >()))
        return *Shiboken::Converter< QLineF* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QLine >::checkType(pyobj))
        return QLineF(Shiboken::Converter< ::QLine >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QLineF >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QPointF >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QPointF >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QPointF >());
    return Shiboken::Converter< ::QPoint >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QPointF Shiboken::Converter< ::QPointF >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QPointF >()))
        return *Shiboken::Converter< QPointF* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QPoint >::checkType(pyobj))
        return QPointF(Shiboken::Converter< ::QPoint >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QPointF >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QDir >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QDir >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QDir >());
    return Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QDir Shiboken::Converter< ::QDir >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QDir >()))
        return *Shiboken::Converter< QDir* >::toCpp(pyobj);
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QDir(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QDir >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QFileInfo >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QFileInfo >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QFileInfo >());
    return Shiboken::Converter< ::QFile >::checkType(pyobj)
         || Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QFileInfo Shiboken::Converter< ::QFileInfo >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QFileInfo >()))
        return *Shiboken::Converter< QFileInfo* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QFile >::checkType(pyobj))
        return QFileInfo(Shiboken::Converter< ::QFile >::toCpp(pyobj));
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QFileInfo(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QFileInfo >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QLocale >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QLocale >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QLocale >());
    return Shiboken::Converter< ::QLocale::Language >::checkType(pyobj)
         || Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QLocale Shiboken::Converter< ::QLocale >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QLocale >()))
        return *Shiboken::Converter< QLocale* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QLocale::Language >::checkType(pyobj))
        return QLocale(Shiboken::Converter< ::QLocale::Language >::toCpp(pyobj));
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QLocale(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QLocale >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QUuid >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QUuid >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QUuid >());
    return Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QUuid Shiboken::Converter< ::QUuid >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QUuid >()))
        return *Shiboken::Converter< QUuid* >::toCpp(pyobj);
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QUuid(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QUuid >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QPersistentModelIndex >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QPersistentModelIndex >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QPersistentModelIndex >());
    return Shiboken::Converter< ::QModelIndex >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QPersistentModelIndex Shiboken::Converter< ::QPersistentModelIndex >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QPersistentModelIndex >()))
        return *Shiboken::Converter< QPersistentModelIndex* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QModelIndex >::checkType(pyobj))
        return QPersistentModelIndex(Shiboken::Converter< ::QModelIndex >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QPersistentModelIndex >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QEasingCurve >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QEasingCurve >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QEasingCurve >());
    return Shiboken::Converter< ::QEasingCurve::Type >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QEasingCurve Shiboken::Converter< ::QEasingCurve >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QEasingCurve >()))
        return *Shiboken::Converter< QEasingCurve* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QEasingCurve::Type >::checkType(pyobj))
        return QEasingCurve(Shiboken::Converter< ::QEasingCurve::Type >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QEasingCurve >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QByteArray >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QByteArray >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QByteArray >());
    return Shiboken::Converter< const char * >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QByteArray Shiboken::Converter< ::QByteArray >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QByteArray >()))
        return *Shiboken::Converter< QByteArray* >::toCpp(pyobj);
    else if (Shiboken::Converter< const char * >::checkType(pyobj))
        return QByteArray(Shiboken::Converter< const char * >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QByteArray >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QUrl >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QUrl >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QUrl >());
    return Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QUrl Shiboken::Converter< ::QUrl >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QUrl >()))
        return *Shiboken::Converter< QUrl* >::toCpp(pyobj);
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QUrl(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QUrl >::toCpp(pyobj);
}


#endif // SBK_QTCORE_PYTHON_H

