/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */



#ifndef SBK_QTNETWORK_PYTHON_H
#define SBK_QTNETWORK_PYTHON_H

//workaround to access protected functions
#define protected public

#include <Python.h>
#include <conversions.h>
#include <sbkenum.h>
#include <basewrapper.h>
#include <bindingmanager.h>
#include <memory>

#include <pysidesignal.h>
// Module Includes
#include <pyside_qtcore_python.h>

// Binded library includes
#include <qsslconfiguration.h>
#include <qnetworkconfiguration.h>
#include <qlocalserver.h>
#include <qhostaddress.h>
#include <qhostinfo.h>
#include <qnetworkrequest.h>
#include <qsslsocket.h>
#include <qnetworksession.h>
#include <qnetworkconfigmanager.h>
#include <qnetworkcookiejar.h>
#include <qssl.h>
#include <qnetworkdiskcache.h>
#include <qnetworkcookie.h>
#include <qnetworkaccessmanager.h>
#include <qudpsocket.h>
#include <qnetworkproxy.h>
#include <qnetworkinterface.h>
#include <qtcpsocket.h>
#include <qnetworkreply.h>
#include <qabstractnetworkcache.h>
#include <qftp.h>
#include <qabstractsocket.h>
#include <qtcpserver.h>
#include <qsslerror.h>
#include <qsslcipher.h>
#include <qauthenticator.h>
#include <qurlinfo.h>
#include <qsslkey.h>
#include <qhttp.h>
#include <qlocalsocket.h>
// Conversion Includes - Primitive Types
#include <QString>
#include <signalmanager.h>
#include <typeresolver.h>
#include <QtConcurrentFilter>
#include <QTextDocument>

// Conversion Includes - Container Types
#include <QList>
#include <QMap>
#include <QStack>
#include <QMultiMap>
#include <QVector>
#include <QPair>
#include <pysideconversions.h>
#include <QSet>
#include <qqueue.h>
#include <QStringList>
#include <qlinkedlist.h>

// Type indices
#define SBK_QSSL_IDX                                                 0
#define SBK_QSSL_KEYTYPE_IDX                                         1
#define SBK_QSSL_KEYALGORITHM_IDX                                    2
#define SBK_QSSL_SSLPROTOCOL_IDX                                     3
#define SBK_QSSL_ALTERNATENAMEENTRYTYPE_IDX                          4
#define SBK_QSSL_ENCODINGFORMAT_IDX                                  5
#define SBK_QSSLCONFIGURATION_IDX                                    6
#define SBK_QSSLERROR_IDX                                            7
#define SBK_QSSLERROR_SSLERROR_IDX                                   8
#define SBK_QSSLCIPHER_IDX                                           9
#define SBK_QHTTPHEADER_IDX                                          10
#define SBK_QHTTPREQUESTHEADER_IDX                                   11
#define SBK_QHTTPRESPONSEHEADER_IDX                                  12
#define SBK_QNETWORKCACHEMETADATA_IDX                                13
#define SBK_QNETWORKCONFIGURATION_IDX                                14
#define SBK_QNETWORKCONFIGURATION_BEARERTYPE_IDX                     15
#define SBK_QNETWORKCONFIGURATION_PURPOSE_IDX                        16
#define SBK_QNETWORKCONFIGURATION_TYPE_IDX                           17
#define SBK_QNETWORKCONFIGURATION_STATEFLAG_IDX                      18
#define SBK_QFLAGS_QNETWORKCONFIGURATION_STATEFLAG__IDX              19
#define SBK_QURLINFO_IDX                                             20
#define SBK_QURLINFO_PERMISSIONSPEC_IDX                              21
#define SBK_QNETWORKPROXY_IDX                                        22
#define SBK_QNETWORKPROXY_PROXYTYPE_IDX                              23
#define SBK_QNETWORKPROXY_CAPABILITY_IDX                             24
#define SBK_QNETWORKINTERFACE_IDX                                    25
#define SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                      26
#define SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG__IDX              27
#define SBK_QNETWORKADDRESSENTRY_IDX                                 28
#define SBK_QHOSTINFO_IDX                                            29
#define SBK_QHOSTINFO_HOSTINFOERROR_IDX                              30
#define SBK_QHOSTADDRESS_IDX                                         31
#define SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                          32
#define SBK_QIPV6ADDRESS_IDX                                         33
#define SBK_QAUTHENTICATOR_IDX                                       34
#define SBK_QNETWORKREQUEST_IDX                                      35
#define SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                     36
#define SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                         37
#define SBK_QNETWORKREQUEST_PRIORITY_IDX                             38
#define SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                            39
#define SBK_QNETWORKREQUEST_LOADCONTROL_IDX                          40
#define SBK_QABSTRACTSOCKET_IDX                                      41
#define SBK_QABSTRACTSOCKET_SOCKETTYPE_IDX                           42
#define SBK_QABSTRACTSOCKET_SOCKETERROR_IDX                          43
#define SBK_QABSTRACTSOCKET_NETWORKLAYERPROTOCOL_IDX                 44
#define SBK_QABSTRACTSOCKET_SOCKETOPTION_IDX                         45
#define SBK_QABSTRACTSOCKET_SOCKETSTATE_IDX                          46
#define SBK_QUDPSOCKET_IDX                                           47
#define SBK_QUDPSOCKET_BINDFLAG_IDX                                  48
#define SBK_QFLAGS_QUDPSOCKET_BINDFLAG__IDX                          49
#define SBK_QTCPSOCKET_IDX                                           50
#define SBK_QLOCALSOCKET_IDX                                         51
#define SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                        52
#define SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                        53
#define SBK_QNETWORKREPLY_IDX                                        54
#define SBK_QNETWORKREPLY_NETWORKERROR_IDX                           55
#define SBK_QNETWORKACCESSMANAGER_IDX                                56
#define SBK_QNETWORKACCESSMANAGER_NETWORKACCESSIBILITY_IDX           57
#define SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                      58
#define SBK_QHTTP_IDX                                                59
#define SBK_QHTTP_ERROR_IDX                                          60
#define SBK_QHTTP_CONNECTIONMODE_IDX                                 61
#define SBK_QHTTP_STATE_IDX                                          62
#define SBK_QFTP_IDX                                                 63
#define SBK_QFTP_TRANSFERTYPE_IDX                                    64
#define SBK_QFTP_ERROR_IDX                                           65
#define SBK_QFTP_COMMAND_IDX                                         66
#define SBK_QFTP_TRANSFERMODE_IDX                                    67
#define SBK_QFTP_STATE_IDX                                           68
#define SBK_QABSTRACTNETWORKCACHE_IDX                                69
#define SBK_QNETWORKDISKCACHE_IDX                                    70
#define SBK_QNETWORKSESSION_IDX                                      71
#define SBK_QNETWORKSESSION_SESSIONERROR_IDX                         72
#define SBK_QNETWORKSESSION_STATE_IDX                                73
#define SBK_QTCPSERVER_IDX                                           74
#define SBK_QNETWORKCONFIGURATIONMANAGER_IDX                         75
#define SBK_QNETWORKCONFIGURATIONMANAGER_CAPABILITY_IDX              76
#define SBK_QFLAGS_QNETWORKCONFIGURATIONMANAGER_CAPABILITY__IDX      77
#define SBK_QLOCALSERVER_IDX                                         78
#define SBK_QNETWORKCOOKIEJAR_IDX                                    79
#define SBK_QNETWORKCOOKIE_IDX                                       80
#define SBK_QNETWORKCOOKIE_RAWFORM_IDX                               81
#define SBK_QSSLKEY_IDX                                              82
#define SBK_QSSLSOCKET_IDX                                           83
#define SBK_QSSLSOCKET_SSLMODE_IDX                                   84
#define SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                            85
#define SBK_QtNetwork_IDX_COUNT                                      86

// This variable stores all python types exported by this module
extern PyTypeObject** SbkPySide_QtNetworkTypes;

// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject* SbkType< ::QSsl::KeyType >() { return SbkPySide_QtNetworkTypes[SBK_QSSL_KEYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSsl::KeyAlgorithm >() { return SbkPySide_QtNetworkTypes[SBK_QSSL_KEYALGORITHM_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSsl::SslProtocol >() { return SbkPySide_QtNetworkTypes[SBK_QSSL_SSLPROTOCOL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSsl::AlternateNameEntryType >() { return SbkPySide_QtNetworkTypes[SBK_QSSL_ALTERNATENAMEENTRYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSsl::EncodingFormat >() { return SbkPySide_QtNetworkTypes[SBK_QSSL_ENCODINGFORMAT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSslConfiguration >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QSSLCONFIGURATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSslError::SslError >() { return SbkPySide_QtNetworkTypes[SBK_QSSLERROR_SSLERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSslError >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QSSLERROR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSslCipher >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QSSLCIPHER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHttpHeader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHTTPHEADER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHttpRequestHeader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHTTPREQUESTHEADER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHttpResponseHeader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHTTPRESPONSEHEADER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkCacheMetaData >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKCACHEMETADATA_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkConfiguration::BearerType >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_BEARERTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkConfiguration::Purpose >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_PURPOSE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkConfiguration::Type >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_TYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkConfiguration::StateFlag >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_STATEFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QNetworkConfiguration::StateFlag> >() { return SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKCONFIGURATION_STATEFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkConfiguration >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QUrlInfo::PermissionSpec >() { return SbkPySide_QtNetworkTypes[SBK_QURLINFO_PERMISSIONSPEC_IDX]; }
template<> inline PyTypeObject* SbkType< ::QUrlInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QURLINFO_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkProxy::ProxyType >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_PROXYTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkProxy::Capability >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_CAPABILITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkProxy >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkInterface::InterfaceFlag >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QNetworkInterface::InterfaceFlag> >() { return SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkAddressEntry >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKADDRESSENTRY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHostInfo::HostInfoError >() { return SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHostInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHostAddress::SpecialAddress >() { return SbkPySide_QtNetworkTypes[SBK_QHOSTADDRESS_SPECIALADDRESS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHostAddress >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHOSTADDRESS_IDX]); }
template<> inline PyTypeObject* SbkType< ::QIPv6Address >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QIPV6ADDRESS_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAuthenticator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QAUTHENTICATOR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest::CacheLoadControl >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest::KnownHeaders >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest::Priority >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_PRIORITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest::Attribute >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_ATTRIBUTE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest::LoadControl >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_LOADCONTROL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkRequest >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKREQUEST_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket::SocketType >() { return SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket::SocketError >() { return SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket::NetworkLayerProtocol >() { return SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_NETWORKLAYERPROTOCOL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket::SocketOption >() { return SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETOPTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket::SocketState >() { return SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QAbstractSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_IDX]); }
template<> inline PyTypeObject* SbkType< ::QUdpSocket::BindFlag >() { return SbkPySide_QtNetworkTypes[SBK_QUDPSOCKET_BINDFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QUdpSocket::BindFlag> >() { return SbkPySide_QtNetworkTypes[SBK_QFLAGS_QUDPSOCKET_BINDFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QUdpSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QUDPSOCKET_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTcpSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QTCPSOCKET_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLocalSocket::LocalSocketState >() { return SbkPySide_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocalSocket::LocalSocketError >() { return SbkPySide_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QLocalSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QLOCALSOCKET_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkReply::NetworkError >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKREPLY_NETWORKERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkReply >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKREPLY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkAccessManager::NetworkAccessibility >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_NETWORKACCESSIBILITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkAccessManager::Operation >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkAccessManager >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QHttp::Error >() { return SbkPySide_QtNetworkTypes[SBK_QHTTP_ERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHttp::ConnectionMode >() { return SbkPySide_QtNetworkTypes[SBK_QHTTP_CONNECTIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHttp::State >() { return SbkPySide_QtNetworkTypes[SBK_QHTTP_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QHttp >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QHTTP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QFtp::TransferType >() { return SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFtp::Error >() { return SbkPySide_QtNetworkTypes[SBK_QFTP_ERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFtp::Command >() { return SbkPySide_QtNetworkTypes[SBK_QFTP_COMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFtp::TransferMode >() { return SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFtp::State >() { return SbkPySide_QtNetworkTypes[SBK_QFTP_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFtp >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QFTP_IDX]); }
template<> inline PyTypeObject* SbkType< ::QAbstractNetworkCache >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QABSTRACTNETWORKCACHE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkDiskCache >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKDISKCACHE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkSession::SessionError >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKSESSION_SESSIONERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkSession::State >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKSESSION_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkSession >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKSESSION_IDX]); }
template<> inline PyTypeObject* SbkType< ::QTcpServer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QTCPSERVER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkConfigurationManager::Capability >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATIONMANAGER_CAPABILITY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QNetworkConfigurationManager::Capability> >() { return SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKCONFIGURATIONMANAGER_CAPABILITY__IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkConfigurationManager >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATIONMANAGER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QLocalServer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QLOCALSERVER_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkCookieJar >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKCOOKIEJAR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QNetworkCookie::RawForm >() { return SbkPySide_QtNetworkTypes[SBK_QNETWORKCOOKIE_RAWFORM_IDX]; }
template<> inline PyTypeObject* SbkType< ::QNetworkCookie >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QNETWORKCOOKIE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSslKey >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QSSLKEY_IDX]); }
template<> inline PyTypeObject* SbkType< ::QSslSocket::SslMode >() { return SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_SSLMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSslSocket::PeerVerifyMode >() { return SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_PEERVERIFYMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QSslSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_IDX]); }

template<>
inline PyObject* createWrapper<QAbstractSocket >(const QAbstractSocket* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractSocket* value = const_cast<QAbstractSocket* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractSocket >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QUdpSocket >(const QUdpSocket* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QUdpSocket* value = const_cast<QUdpSocket* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QUdpSocket >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTcpSocket >(const QTcpSocket* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTcpSocket* value = const_cast<QTcpSocket* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTcpSocket >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QLocalSocket >(const QLocalSocket* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QLocalSocket* value = const_cast<QLocalSocket* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QLocalSocket >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkReply >(const QNetworkReply* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkReply* value = const_cast<QNetworkReply* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkReply >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkAccessManager >(const QNetworkAccessManager* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkAccessManager* value = const_cast<QNetworkAccessManager* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkAccessManager >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHttp >(const QHttp* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QHttp* value = const_cast<QHttp* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QHttp >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QFtp >(const QFtp* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QFtp* value = const_cast<QFtp* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QFtp >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QAbstractNetworkCache >(const QAbstractNetworkCache* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QAbstractNetworkCache* value = const_cast<QAbstractNetworkCache* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QAbstractNetworkCache >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkDiskCache >(const QNetworkDiskCache* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkDiskCache* value = const_cast<QNetworkDiskCache* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkDiskCache >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkSession >(const QNetworkSession* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkSession* value = const_cast<QNetworkSession* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkSession >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QTcpServer >(const QTcpServer* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QTcpServer* value = const_cast<QTcpServer* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QTcpServer >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkConfigurationManager >(const QNetworkConfigurationManager* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkConfigurationManager* value = const_cast<QNetworkConfigurationManager* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkConfigurationManager >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QLocalServer >(const QLocalServer* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QLocalServer* value = const_cast<QLocalServer* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QLocalServer >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QNetworkCookieJar >(const QNetworkCookieJar* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QNetworkCookieJar* value = const_cast<QNetworkCookieJar* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkCookieJar >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QSslSocket >(const QSslSocket* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    QSslSocket* value = const_cast<QSslSocket* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::QSslSocket >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
// Generated converters declarations ----------------------------------

template<>
struct Converter< ::QSsl::KeyType > : EnumConverter< ::QSsl::KeyType >
{
};

template<>
struct Converter< ::QSsl::KeyAlgorithm > : EnumConverter< ::QSsl::KeyAlgorithm >
{
};

template<>
struct Converter< ::QSsl::SslProtocol > : EnumConverter< ::QSsl::SslProtocol >
{
};

template<>
struct Converter< ::QSsl::AlternateNameEntryType > : EnumConverter< ::QSsl::AlternateNameEntryType >
{
};

template<>
struct Converter< ::QSsl::EncodingFormat > : EnumConverter< ::QSsl::EncodingFormat >
{
};

template<>
struct Converter< ::QSslConfiguration > : ValueTypeConverter< ::QSslConfiguration >
{
};

template<>
struct Converter< ::QSslError::SslError > : EnumConverter< ::QSslError::SslError >
{
};

template<>
struct Converter< ::QSslError > : ValueTypeConverter< ::QSslError >
{
    static ::QSslError toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QSslCipher > : ValueTypeConverter< ::QSslCipher >
{
};

template<>
struct Converter< ::QHttpHeader* > : ObjectTypeConverter< ::QHttpHeader >
{
};

template<>
struct Converter< ::QHttpHeader > : ObjectTypeReferenceConverter< ::QHttpHeader >
{
};

template <>
struct SbkTypeInfo<QHttpRequestHeader >
{
    static const bool isCppWrapper = true;
};
template<>
struct Converter< ::QHttpRequestHeader > : ValueTypeConverter< ::QHttpRequestHeader >
{
    static ::QHttpRequestHeader toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template <>
struct SbkTypeInfo<QHttpResponseHeader >
{
    static const bool isCppWrapper = true;
};
template<>
struct Converter< ::QHttpResponseHeader > : ValueTypeConverter< ::QHttpResponseHeader >
{
    static ::QHttpResponseHeader toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QNetworkCacheMetaData > : ValueTypeConverter< ::QNetworkCacheMetaData >
{
};

template<>
struct Converter< ::QNetworkConfiguration::BearerType > : EnumConverter< ::QNetworkConfiguration::BearerType >
{
};

template<>
struct Converter< ::QNetworkConfiguration::Purpose > : EnumConverter< ::QNetworkConfiguration::Purpose >
{
};

template<>
struct Converter< ::QNetworkConfiguration::Type > : EnumConverter< ::QNetworkConfiguration::Type >
{
};

template<>
struct Converter< ::QNetworkConfiguration::StateFlag > : EnumConverter< ::QNetworkConfiguration::StateFlag >
{
};
template<>
struct Converter< ::QFlags<QNetworkConfiguration::StateFlag> > : QFlagsConverter< ::QFlags<QNetworkConfiguration::StateFlag> >
{
};

template<>
struct Converter< ::QNetworkConfiguration > : ValueTypeConverter< ::QNetworkConfiguration >
{
};

template<>
struct Converter< ::QUrlInfo::PermissionSpec > : EnumConverter< ::QUrlInfo::PermissionSpec >
{
};

template <>
struct SbkTypeInfo<QUrlInfo >
{
    static const bool isCppWrapper = true;
};
template<>
struct Converter< ::QUrlInfo > : ValueTypeConverter< ::QUrlInfo >
{
};

template<>
struct Converter< ::QNetworkProxy::ProxyType > : EnumConverter< ::QNetworkProxy::ProxyType >
{
};

template<>
struct Converter< ::QNetworkProxy::Capability > : EnumConverter< ::QNetworkProxy::Capability >
{
};

template<>
struct Converter< ::QNetworkProxy > : ValueTypeConverter< ::QNetworkProxy >
{
    static ::QNetworkProxy toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QNetworkInterface::InterfaceFlag > : EnumConverter< ::QNetworkInterface::InterfaceFlag >
{
};
template<>
struct Converter< ::QFlags<QNetworkInterface::InterfaceFlag> > : QFlagsConverter< ::QFlags<QNetworkInterface::InterfaceFlag> >
{
};

template<>
struct Converter< ::QNetworkInterface > : ValueTypeConverter< ::QNetworkInterface >
{
};

template<>
struct Converter< ::QNetworkAddressEntry > : ValueTypeConverter< ::QNetworkAddressEntry >
{
};

template<>
struct Converter< ::QHostInfo::HostInfoError > : EnumConverter< ::QHostInfo::HostInfoError >
{
};

template<>
struct Converter< ::QHostInfo > : ValueTypeConverter< ::QHostInfo >
{
    static ::QHostInfo toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QHostAddress::SpecialAddress > : EnumConverter< ::QHostAddress::SpecialAddress >
{
};

template<>
struct Converter< ::QHostAddress > : ValueTypeConverter< ::QHostAddress >
{
    static ::QHostAddress toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::QIPv6Address > : ValueTypeConverter< ::QIPv6Address >
{
};

template<>
struct Converter< ::QAuthenticator > : ValueTypeConverter< ::QAuthenticator >
{
};

template<>
struct Converter< ::QNetworkRequest::CacheLoadControl > : EnumConverter< ::QNetworkRequest::CacheLoadControl >
{
};

template<>
struct Converter< ::QNetworkRequest::KnownHeaders > : EnumConverter< ::QNetworkRequest::KnownHeaders >
{
};

template<>
struct Converter< ::QNetworkRequest::Priority > : EnumConverter< ::QNetworkRequest::Priority >
{
};

template<>
struct Converter< ::QNetworkRequest::Attribute > : EnumConverter< ::QNetworkRequest::Attribute >
{
};

template<>
struct Converter< ::QNetworkRequest::LoadControl > : EnumConverter< ::QNetworkRequest::LoadControl >
{
};

template<>
struct Converter< ::QNetworkRequest > : ValueTypeConverter< ::QNetworkRequest >
{
};

template<>
struct Converter< ::QAbstractSocket::SocketType > : EnumConverter< ::QAbstractSocket::SocketType >
{
};

template<>
struct Converter< ::QAbstractSocket::SocketError > : EnumConverter< ::QAbstractSocket::SocketError >
{
};

template<>
struct Converter< ::QAbstractSocket::NetworkLayerProtocol > : EnumConverter< ::QAbstractSocket::NetworkLayerProtocol >
{
};

template<>
struct Converter< ::QAbstractSocket::SocketOption > : EnumConverter< ::QAbstractSocket::SocketOption >
{
};

template<>
struct Converter< ::QAbstractSocket::SocketState > : EnumConverter< ::QAbstractSocket::SocketState >
{
};

template<>
struct Converter< ::QAbstractSocket* > : ObjectTypeConverter< ::QAbstractSocket >
{
};

template<>
struct Converter< ::QAbstractSocket > : ObjectTypeReferenceConverter< ::QAbstractSocket >
{
};

template<>
struct Converter< ::QUdpSocket::BindFlag > : EnumConverter< ::QUdpSocket::BindFlag >
{
};
template<>
struct Converter< ::QFlags<QUdpSocket::BindFlag> > : QFlagsConverter< ::QFlags<QUdpSocket::BindFlag> >
{
};

template<>
struct Converter< ::QUdpSocket* > : ObjectTypeConverter< ::QUdpSocket >
{
};

template<>
struct Converter< ::QUdpSocket > : ObjectTypeReferenceConverter< ::QUdpSocket >
{
};

template<>
struct Converter< ::QTcpSocket* > : ObjectTypeConverter< ::QTcpSocket >
{
};

template<>
struct Converter< ::QTcpSocket > : ObjectTypeReferenceConverter< ::QTcpSocket >
{
};

template<>
struct Converter< ::QLocalSocket::LocalSocketState > : EnumConverter< ::QLocalSocket::LocalSocketState >
{
};

template<>
struct Converter< ::QLocalSocket::LocalSocketError > : EnumConverter< ::QLocalSocket::LocalSocketError >
{
};

template<>
struct Converter< ::QLocalSocket* > : ObjectTypeConverter< ::QLocalSocket >
{
};

template<>
struct Converter< ::QLocalSocket > : ObjectTypeReferenceConverter< ::QLocalSocket >
{
};

template<>
struct Converter< ::QNetworkReply::NetworkError > : EnumConverter< ::QNetworkReply::NetworkError >
{
};

template<>
struct Converter< ::QNetworkReply* > : ObjectTypeConverter< ::QNetworkReply >
{
};

template<>
struct Converter< ::QNetworkReply > : ObjectTypeReferenceConverter< ::QNetworkReply >
{
};

template<>
struct Converter< ::QNetworkAccessManager::NetworkAccessibility > : EnumConverter< ::QNetworkAccessManager::NetworkAccessibility >
{
};

template<>
struct Converter< ::QNetworkAccessManager::Operation > : EnumConverter< ::QNetworkAccessManager::Operation >
{
};

template<>
struct Converter< ::QNetworkAccessManager* > : ObjectTypeConverter< ::QNetworkAccessManager >
{
};

template<>
struct Converter< ::QNetworkAccessManager > : ObjectTypeReferenceConverter< ::QNetworkAccessManager >
{
};

template<>
struct Converter< ::QHttp::Error > : EnumConverter< ::QHttp::Error >
{
};

template<>
struct Converter< ::QHttp::ConnectionMode > : EnumConverter< ::QHttp::ConnectionMode >
{
};

template<>
struct Converter< ::QHttp::State > : EnumConverter< ::QHttp::State >
{
};

template<>
struct Converter< ::QHttp* > : ObjectTypeConverter< ::QHttp >
{
};

template<>
struct Converter< ::QHttp > : ObjectTypeReferenceConverter< ::QHttp >
{
};

template<>
struct Converter< ::QFtp::TransferType > : EnumConverter< ::QFtp::TransferType >
{
};

template<>
struct Converter< ::QFtp::Error > : EnumConverter< ::QFtp::Error >
{
};

template<>
struct Converter< ::QFtp::Command > : EnumConverter< ::QFtp::Command >
{
};

template<>
struct Converter< ::QFtp::TransferMode > : EnumConverter< ::QFtp::TransferMode >
{
};

template<>
struct Converter< ::QFtp::State > : EnumConverter< ::QFtp::State >
{
};

template<>
struct Converter< ::QFtp* > : ObjectTypeConverter< ::QFtp >
{
};

template<>
struct Converter< ::QFtp > : ObjectTypeReferenceConverter< ::QFtp >
{
};

template<>
struct Converter< ::QAbstractNetworkCache* > : ObjectTypeConverter< ::QAbstractNetworkCache >
{
};

template<>
struct Converter< ::QAbstractNetworkCache > : ObjectTypeReferenceConverter< ::QAbstractNetworkCache >
{
};

template<>
struct Converter< ::QNetworkDiskCache* > : ObjectTypeConverter< ::QNetworkDiskCache >
{
};

template<>
struct Converter< ::QNetworkDiskCache > : ObjectTypeReferenceConverter< ::QNetworkDiskCache >
{
};

template<>
struct Converter< ::QNetworkSession::SessionError > : EnumConverter< ::QNetworkSession::SessionError >
{
};

template<>
struct Converter< ::QNetworkSession::State > : EnumConverter< ::QNetworkSession::State >
{
};

template<>
struct Converter< ::QNetworkSession* > : ObjectTypeConverter< ::QNetworkSession >
{
};

template<>
struct Converter< ::QNetworkSession > : ObjectTypeReferenceConverter< ::QNetworkSession >
{
};

template<>
struct Converter< ::QTcpServer* > : ObjectTypeConverter< ::QTcpServer >
{
};

template<>
struct Converter< ::QTcpServer > : ObjectTypeReferenceConverter< ::QTcpServer >
{
};

template<>
struct Converter< ::QNetworkConfigurationManager::Capability > : EnumConverter< ::QNetworkConfigurationManager::Capability >
{
};
template<>
struct Converter< ::QFlags<QNetworkConfigurationManager::Capability> > : QFlagsConverter< ::QFlags<QNetworkConfigurationManager::Capability> >
{
};

template<>
struct Converter< ::QNetworkConfigurationManager* > : ObjectTypeConverter< ::QNetworkConfigurationManager >
{
};

template<>
struct Converter< ::QNetworkConfigurationManager > : ObjectTypeReferenceConverter< ::QNetworkConfigurationManager >
{
};

template<>
struct Converter< ::QLocalServer* > : ObjectTypeConverter< ::QLocalServer >
{
};

template<>
struct Converter< ::QLocalServer > : ObjectTypeReferenceConverter< ::QLocalServer >
{
};

template<>
struct Converter< ::QNetworkCookieJar* > : ObjectTypeConverter< ::QNetworkCookieJar >
{
};

template<>
struct Converter< ::QNetworkCookieJar > : ObjectTypeReferenceConverter< ::QNetworkCookieJar >
{
};

template<>
struct Converter< ::QNetworkCookie::RawForm > : EnumConverter< ::QNetworkCookie::RawForm >
{
};

template<>
struct Converter< ::QNetworkCookie > : ValueTypeConverter< ::QNetworkCookie >
{
};

template<>
struct Converter< ::QSslKey > : ValueTypeConverter< ::QSslKey >
{
};

template<>
struct Converter< ::QSslSocket::SslMode > : EnumConverter< ::QSslSocket::SslMode >
{
};

template<>
struct Converter< ::QSslSocket::PeerVerifyMode > : EnumConverter< ::QSslSocket::PeerVerifyMode >
{
};

template<>
struct Converter< ::QSslSocket* > : ObjectTypeConverter< ::QSslSocket >
{
};

template<>
struct Converter< ::QSslSocket > : ObjectTypeReferenceConverter< ::QSslSocket >
{
};

} // namespace Shiboken

// User defined converters --------------------------------------------
// Generated converters implemantations -------------------------------

inline bool Shiboken::Converter< ::QSslError >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QSslError >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QSslError >());
    return Shiboken::Converter< ::QSslError::SslError >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QSslError Shiboken::Converter< ::QSslError >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QSslError >()))
        return *Shiboken::Converter< QSslError* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QSslError::SslError >::checkType(pyobj))
        return QSslError(Shiboken::Converter< ::QSslError::SslError >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QSslError >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QHttpRequestHeader >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QHttpRequestHeader >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QHttpRequestHeader >());
    return Shiboken::Converter< QString >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QHttpRequestHeader Shiboken::Converter< ::QHttpRequestHeader >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QHttpRequestHeader >()))
        return *Shiboken::Converter< QHttpRequestHeader* >::toCpp(pyobj);
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QHttpRequestHeader(Shiboken::Converter< QString >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QHttpRequestHeader >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QHttpResponseHeader >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QHttpResponseHeader >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QHttpResponseHeader >());
    return Shiboken::Converter< QString >::checkType(pyobj)
         || PyInt_Check(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QHttpResponseHeader Shiboken::Converter< ::QHttpResponseHeader >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QHttpResponseHeader >()))
        return *Shiboken::Converter< QHttpResponseHeader* >::toCpp(pyobj);
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return QHttpResponseHeader(Shiboken::Converter< QString >::toCpp(pyobj));
    else if (PyInt_Check(pyobj))
        return QHttpResponseHeader(Shiboken::Converter< int >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QHttpResponseHeader >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QNetworkProxy >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QNetworkProxy >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QNetworkProxy >());
    return Shiboken::Converter< ::QNetworkProxy::ProxyType >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QNetworkProxy Shiboken::Converter< ::QNetworkProxy >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QNetworkProxy >()))
        return *Shiboken::Converter< QNetworkProxy* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QNetworkProxy::ProxyType >::checkType(pyobj))
        return QNetworkProxy(Shiboken::Converter< ::QNetworkProxy::ProxyType >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QNetworkProxy >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QHostInfo >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QHostInfo >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QHostInfo >());
    return PyInt_Check(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QHostInfo Shiboken::Converter< ::QHostInfo >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QHostInfo >()))
        return *Shiboken::Converter< QHostInfo* >::toCpp(pyobj);
    else if (PyInt_Check(pyobj))
        return QHostInfo(Shiboken::Converter< int >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QHostInfo >::toCpp(pyobj);
}

inline bool Shiboken::Converter< ::QHostAddress >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::QHostAddress >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::QHostAddress >());
    return Shiboken::Converter< ::QHostAddress::SpecialAddress >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::QHostAddress Shiboken::Converter< ::QHostAddress >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::QHostAddress >()))
        return *Shiboken::Converter< QHostAddress* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::QHostAddress::SpecialAddress >::checkType(pyobj))
        return QHostAddress(Shiboken::Converter< ::QHostAddress::SpecialAddress >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::QHostAddress >::toCpp(pyobj);
}


#endif // SBK_QTNETWORK_PYTHON_H

