/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */



#ifndef SBK_PHONON_PYTHON_H
#define SBK_PHONON_PYTHON_H

//workaround to access protected functions
#define protected public

#include <Python.h>
#include <conversions.h>
#include <sbkenum.h>
#include <basewrapper.h>
#include <bindingmanager.h>
#include <memory>

#include <pysidesignal.h>
// Module Includes
#include <pyside_qtgui_python.h>
#include <pyside_qtcore_python.h>

// Binded library includes
#include <phononnamespace.h>
#include <backendinterface.h>
#include <mediaobjectinterface.h>
#include <videowidget.h>
#include <audiooutput.h>
#include <effectparameter.h>
#include <path.h>
#include <mediacontroller.h>
#include <abstractmediastream.h>
#include <streaminterface.h>
#include <seekslider.h>
#include "pyside_phonon.h"
#include <effectinterface.h>
#include <objectdescriptionmodel.h>
#include <abstractvideooutput.h>
#include <objectdescription.h>
#include <mediaobject.h>
#include <abstractaudiooutput.h>
#include <volumeslider.h>
#include <platformplugin.h>
#include <volumefadereffect.h>
#include <mediasource.h>
#include <medianode.h>
#include <backendcapabilities.h>
#include <effectwidget.h>
#include <videoplayer.h>
#include <volumefaderinterface.h>
#include <addoninterface.h>
#include <videowidgetinterface.h>
#include <effect.h>
// Conversion Includes - Primitive Types
#include <QString>
#include <signalmanager.h>
#include <typeresolver.h>
#include <QTextDocument>
#include <QtConcurrentFilter>

// Conversion Includes - Container Types
#include <QMap>
#include <QStack>
#include <QVector>
#include <QStringList>
#include <QSet>
#include <QPair>
#include <pysideconversions.h>
#include <qqueue.h>
#include <QList>
#include <QMultiMap>

// Type indices
#define SBK_PHONON_IDX                                               0
#define SBK_PHONON_DISCTYPE_IDX                                      1
#define SBK_PHONON_METADATA_IDX                                      2
#define SBK_PHONON_CATEGORY_IDX                                      3
#define SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX                         4
#define SBK_PHONON_STATE_IDX                                         5
#define SBK_PHONON_ERRORTYPE_IDX                                     6
#define SBK_PHONON_BACKENDCAPABILITIES_IDX                           7
#define SBK_PHONON_AUDIOCHANNELDESCRIPTION_IDX                       8
#define SBK_PHONON_AUDIOOUTPUTDEVICE_IDX                             9
#define SBK_PHONON_AUDIOCAPTUREDEVICE_IDX                            10
#define SBK_PHONON_SUBTITLEDESCRIPTION_IDX                           11
#define SBK_PHONON_EFFECTDESCRIPTION_IDX                             12
#define SBK_PHONON_VOLUMEFADERINTERFACE_IDX                          13
#define SBK_PHONON_VIDEOWIDGETINTERFACE_IDX                          14
#define SBK_PHONON_STREAMINTERFACE_IDX                               15
#define SBK_PHONON_PLATFORMPLUGIN_IDX                                16
#define SBK_PHONON_MEDIAOBJECTINTERFACE_IDX                          17
#define SBK_PHONON_MEDIASOURCE_IDX                                   18
#define SBK_PHONON_MEDIASOURCE_TYPE_IDX                              19
#define SBK_PHONON_EFFECTPARAMETER_IDX                               20
#define SBK_PHONON_EFFECTPARAMETER_HINT_IDX                          21
#define SBK_QFLAGS_PHONON_EFFECTPARAMETER_HINT__IDX                  22
#define SBK_PHONON_EFFECTINTERFACE_IDX                               23
#define SBK_PHONON_BACKENDINTERFACE_IDX                              24
#define SBK_PHONON_BACKENDINTERFACE_CLASS_IDX                        25
#define SBK_PHONON_ADDONINTERFACE_IDX                                26
#define SBK_PHONON_ADDONINTERFACE_SUBTITLECOMMAND_IDX                27
#define SBK_PHONON_ADDONINTERFACE_TITLECOMMAND_IDX                   28
#define SBK_PHONON_ADDONINTERFACE_INTERFACE_IDX                      29
#define SBK_PHONON_ADDONINTERFACE_AUDIOCHANNELCOMMAND_IDX            30
#define SBK_PHONON_ADDONINTERFACE_CHAPTERCOMMAND_IDX                 31
#define SBK_PHONON_ADDONINTERFACE_NAVIGATIONCOMMAND_IDX              32
#define SBK_PHONON_ADDONINTERFACE_ANGLECOMMAND_IDX                   33
#define SBK_PHONON_MEDIANODE_IDX                                     34
#define SBK_PHONON_ABSTRACTVIDEOOUTPUT_IDX                           35
#define SBK_PHONON_PATH_IDX                                          36
#define SBK_PHONON_EFFECTWIDGET_IDX                                  37
#define SBK_PHONON_VOLUMESLIDER_IDX                                  38
#define SBK_PHONON_VIDEOWIDGET_IDX                                   39
#define SBK_PHONON_VIDEOWIDGET_ASPECTRATIO_IDX                       40
#define SBK_PHONON_VIDEOWIDGET_SCALEMODE_IDX                         41
#define SBK_PHONON_VIDEOPLAYER_IDX                                   42
#define SBK_PHONON_SEEKSLIDER_IDX                                    43
#define SBK_PHONON_EFFECTDESCRIPTIONMODEL_IDX                        44
#define SBK_PHONON_AUDIOOUTPUTDEVICEMODEL_IDX                        45
#define SBK_PHONON_BACKENDCAPABILITIES_NOTIFIERWRAPPER_IDX           46
#define SBK_PHONON_MEDIAOBJECT_IDX                                   47
#define SBK_PHONON_MEDIACONTROLLER_IDX                               48
#define SBK_PHONON_MEDIACONTROLLER_FEATURE_IDX                       49
#define SBK_QFLAGS_PHONON_MEDIACONTROLLER_FEATURE__IDX               50
#define SBK_PHONON_EFFECT_IDX                                        51
#define SBK_PHONON_VOLUMEFADEREFFECT_IDX                             52
#define SBK_PHONON_VOLUMEFADEREFFECT_FADECURVE_IDX                   53
#define SBK_PHONON_ABSTRACTMEDIASTREAM_IDX                           54
#define SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX                           55
#define SBK_PHONON_AUDIOOUTPUT_IDX                                   56
#define SBK_phonon_IDX_COUNT                                         57

// This variable stores all python types exported by this module
extern PyTypeObject** SbkPySide_phononTypes;

// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject* SbkType< ::Phonon::DiscType >() { return SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::MetaData >() { return SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::Category >() { return SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::ObjectDescriptionType >() { return SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::State >() { return SbkPySide_phononTypes[SBK_PHONON_STATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::ErrorType >() { return SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AudioChannelDescription >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_AUDIOCHANNELDESCRIPTION_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AudioOutputDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_AUDIOOUTPUTDEVICE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AudioCaptureDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_AUDIOCAPTUREDEVICE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::SubtitleDescription >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_SUBTITLEDESCRIPTION_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectDescription >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTDESCRIPTION_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VolumeFaderInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADERINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VideoWidgetInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VIDEOWIDGETINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::StreamInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_STREAMINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::PlatformPlugin >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_PLATFORMPLUGIN_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaObjectInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECTINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaSource::Type >() { return SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaSource >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectParameter::Hint >() { return SbkPySide_phononTypes[SBK_PHONON_EFFECTPARAMETER_HINT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Phonon::EffectParameter::Hint> >() { return SbkPySide_phononTypes[SBK_QFLAGS_PHONON_EFFECTPARAMETER_HINT__IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectParameter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTPARAMETER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::BackendInterface::Class >() { return SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_CLASS_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::BackendInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_BACKENDINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::SubtitleCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_SUBTITLECOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::TitleCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_TITLECOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::Interface >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_INTERFACE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::AudioChannelCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_AUDIOCHANNELCOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::ChapterCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_CHAPTERCOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::NavigationCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_NAVIGATIONCOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface::AngleCommand >() { return SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_ANGLECOMMAND_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::AddonInterface >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_ADDONINTERFACE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaNode >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AbstractVideoOutput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTVIDEOOUTPUT_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::Path >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_PATH_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VolumeSlider >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VOLUMESLIDER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VideoWidget::AspectRatio >() { return SbkPySide_phononTypes[SBK_PHONON_VIDEOWIDGET_ASPECTRATIO_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::VideoWidget::ScaleMode >() { return SbkPySide_phononTypes[SBK_PHONON_VIDEOWIDGET_SCALEMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::VideoWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VIDEOWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VideoPlayer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VIDEOPLAYER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::SeekSlider >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_SEEKSLIDER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::EffectDescriptionModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTDESCRIPTIONMODEL_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AudioOutputDeviceModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_AUDIOOUTPUTDEVICEMODEL_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::BackendCapabilities::NotifierWrapper >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_BACKENDCAPABILITIES_NOTIFIERWRAPPER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaObject >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaController::Feature >() { return SbkPySide_phononTypes[SBK_PHONON_MEDIACONTROLLER_FEATURE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<Phonon::MediaController::Feature> >() { return SbkPySide_phononTypes[SBK_QFLAGS_PHONON_MEDIACONTROLLER_FEATURE__IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::MediaController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_MEDIACONTROLLER_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::Effect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_EFFECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::VolumeFaderEffect::FadeCurve >() { return SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADEREFFECT_FADECURVE_IDX]; }
template<> inline PyTypeObject* SbkType< ::Phonon::VolumeFaderEffect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADEREFFECT_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AbstractMediaStream >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTMEDIASTREAM_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AbstractAudioOutput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX]); }
template<> inline PyTypeObject* SbkType< ::Phonon::AudioOutput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_phononTypes[SBK_PHONON_AUDIOOUTPUT_IDX]); }

template<>
inline PyObject* createWrapper<Phonon::EffectWidget >(const Phonon::EffectWidget* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::EffectWidget* value = const_cast<Phonon::EffectWidget* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::EffectWidget >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::VolumeSlider >(const Phonon::VolumeSlider* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::VolumeSlider* value = const_cast<Phonon::VolumeSlider* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::VolumeSlider >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::VideoWidget >(const Phonon::VideoWidget* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::VideoWidget* value = const_cast<Phonon::VideoWidget* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::VideoWidget >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::VideoPlayer >(const Phonon::VideoPlayer* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::VideoPlayer* value = const_cast<Phonon::VideoPlayer* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::VideoPlayer >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::SeekSlider >(const Phonon::SeekSlider* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::SeekSlider* value = const_cast<Phonon::SeekSlider* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::SeekSlider >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::BackendCapabilities::NotifierWrapper >(const Phonon::BackendCapabilities::NotifierWrapper* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::BackendCapabilities::NotifierWrapper* value = const_cast<Phonon::BackendCapabilities::NotifierWrapper* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::BackendCapabilities::NotifierWrapper >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::MediaObject >(const Phonon::MediaObject* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::MediaObject* value = const_cast<Phonon::MediaObject* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::MediaObject >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::MediaController >(const Phonon::MediaController* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::MediaController* value = const_cast<Phonon::MediaController* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::MediaController >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::Effect >(const Phonon::Effect* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::Effect* value = const_cast<Phonon::Effect* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::Effect >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::VolumeFaderEffect >(const Phonon::VolumeFaderEffect* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::VolumeFaderEffect* value = const_cast<Phonon::VolumeFaderEffect* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::VolumeFaderEffect >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::AbstractMediaStream >(const Phonon::AbstractMediaStream* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::AbstractMediaStream* value = const_cast<Phonon::AbstractMediaStream* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::AbstractMediaStream >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::AbstractAudioOutput >(const Phonon::AbstractAudioOutput* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::AbstractAudioOutput* value = const_cast<Phonon::AbstractAudioOutput* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::AbstractAudioOutput >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<Phonon::AudioOutput >(const Phonon::AudioOutput* cppobj, bool hasOwnership, bool isExactType)
{
    const char* typeName = 0;
    Phonon::AudioOutput* value = const_cast<Phonon::AudioOutput* >(cppobj);
    if (!isExactType)
        typeName = typeid(*value).name();
    PyObject* pyObj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::AudioOutput >()),value, hasOwnership, isExactType, typeName);
    PySide::Signal::updateSourceObject(pyObj);
    return pyObj;
}
// Generated converters declarations ----------------------------------

template<>
struct Converter< ::Phonon::DiscType > : EnumConverter< ::Phonon::DiscType >
{
};

template<>
struct Converter< ::Phonon::MetaData > : EnumConverter< ::Phonon::MetaData >
{
};

template<>
struct Converter< ::Phonon::Category > : EnumConverter< ::Phonon::Category >
{
};

template<>
struct Converter< ::Phonon::ObjectDescriptionType > : EnumConverter< ::Phonon::ObjectDescriptionType >
{
};

template<>
struct Converter< ::Phonon::State > : EnumConverter< ::Phonon::State >
{
};

template<>
struct Converter< ::Phonon::ErrorType > : EnumConverter< ::Phonon::ErrorType >
{
};

template<>
struct Converter< ::Phonon::AudioChannelDescription > : ValueTypeConverter< ::Phonon::AudioChannelDescription >
{
};

template<>
struct Converter< ::Phonon::AudioOutputDevice > : ValueTypeConverter< ::Phonon::AudioOutputDevice >
{
};

template<>
struct Converter< ::Phonon::AudioCaptureDevice > : ValueTypeConverter< ::Phonon::AudioCaptureDevice >
{
};

template<>
struct Converter< ::Phonon::SubtitleDescription > : ValueTypeConverter< ::Phonon::SubtitleDescription >
{
};

template<>
struct Converter< ::Phonon::EffectDescription > : ValueTypeConverter< ::Phonon::EffectDescription >
{
};

template<>
struct Converter< ::Phonon::VolumeFaderInterface* > : ObjectTypeConverter< ::Phonon::VolumeFaderInterface >
{
};

template<>
struct Converter< ::Phonon::VolumeFaderInterface > : ObjectTypeReferenceConverter< ::Phonon::VolumeFaderInterface >
{
};

template<>
struct Converter< ::Phonon::VideoWidgetInterface* > : ObjectTypeConverter< ::Phonon::VideoWidgetInterface >
{
};

template<>
struct Converter< ::Phonon::VideoWidgetInterface > : ObjectTypeReferenceConverter< ::Phonon::VideoWidgetInterface >
{
};

template<>
struct Converter< ::Phonon::StreamInterface* > : ObjectTypeConverter< ::Phonon::StreamInterface >
{
};

template<>
struct Converter< ::Phonon::StreamInterface > : ObjectTypeReferenceConverter< ::Phonon::StreamInterface >
{
};

template<>
struct Converter< ::Phonon::PlatformPlugin* > : ObjectTypeConverter< ::Phonon::PlatformPlugin >
{
};

template<>
struct Converter< ::Phonon::PlatformPlugin > : ObjectTypeReferenceConverter< ::Phonon::PlatformPlugin >
{
};

template<>
struct Converter< ::Phonon::MediaObjectInterface* > : ObjectTypeConverter< ::Phonon::MediaObjectInterface >
{
};

template<>
struct Converter< ::Phonon::MediaObjectInterface > : ObjectTypeReferenceConverter< ::Phonon::MediaObjectInterface >
{
};

template<>
struct Converter< ::Phonon::MediaSource::Type > : EnumConverter< ::Phonon::MediaSource::Type >
{
};

template<>
struct Converter< ::Phonon::MediaSource > : ValueTypeConverter< ::Phonon::MediaSource >
{
    static ::Phonon::MediaSource toCpp(PyObject* pyobj);
    static bool isConvertible(PyObject* pyobj);
};

template<>
struct Converter< ::Phonon::EffectParameter::Hint > : EnumConverter< ::Phonon::EffectParameter::Hint >
{
};
template<>
struct Converter< ::QFlags<Phonon::EffectParameter::Hint> > : QFlagsConverter< ::QFlags<Phonon::EffectParameter::Hint> >
{
};

template<>
struct Converter< ::Phonon::EffectParameter > : ValueTypeConverter< ::Phonon::EffectParameter >
{
};

template<>
struct Converter< ::Phonon::EffectInterface* > : ObjectTypeConverter< ::Phonon::EffectInterface >
{
};

template<>
struct Converter< ::Phonon::EffectInterface > : ObjectTypeReferenceConverter< ::Phonon::EffectInterface >
{
};

template<>
struct Converter< ::Phonon::BackendInterface::Class > : EnumConverter< ::Phonon::BackendInterface::Class >
{
};

template<>
struct Converter< ::Phonon::BackendInterface* > : ObjectTypeConverter< ::Phonon::BackendInterface >
{
};

template<>
struct Converter< ::Phonon::BackendInterface > : ObjectTypeReferenceConverter< ::Phonon::BackendInterface >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::SubtitleCommand > : EnumConverter< ::Phonon::AddonInterface::SubtitleCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::TitleCommand > : EnumConverter< ::Phonon::AddonInterface::TitleCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::Interface > : EnumConverter< ::Phonon::AddonInterface::Interface >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::AudioChannelCommand > : EnumConverter< ::Phonon::AddonInterface::AudioChannelCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::ChapterCommand > : EnumConverter< ::Phonon::AddonInterface::ChapterCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::NavigationCommand > : EnumConverter< ::Phonon::AddonInterface::NavigationCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface::AngleCommand > : EnumConverter< ::Phonon::AddonInterface::AngleCommand >
{
};

template<>
struct Converter< ::Phonon::AddonInterface* > : ObjectTypeConverter< ::Phonon::AddonInterface >
{
};

template<>
struct Converter< ::Phonon::AddonInterface > : ObjectTypeReferenceConverter< ::Phonon::AddonInterface >
{
};

template<>
struct Converter< ::Phonon::MediaNode* > : ObjectTypeConverter< ::Phonon::MediaNode >
{
};

template<>
struct Converter< ::Phonon::MediaNode > : ObjectTypeReferenceConverter< ::Phonon::MediaNode >
{
};

template<>
struct Converter< ::Phonon::AbstractVideoOutput* > : ObjectTypeConverter< ::Phonon::AbstractVideoOutput >
{
};

template<>
struct Converter< ::Phonon::AbstractVideoOutput > : ObjectTypeReferenceConverter< ::Phonon::AbstractVideoOutput >
{
};

template<>
struct Converter< ::Phonon::Path > : ValueTypeConverter< ::Phonon::Path >
{
};

template<>
struct Converter< ::Phonon::EffectWidget* > : ObjectTypeConverter< ::Phonon::EffectWidget >
{
};

template<>
struct Converter< ::Phonon::EffectWidget > : ObjectTypeReferenceConverter< ::Phonon::EffectWidget >
{
};

template<>
struct Converter< ::Phonon::VolumeSlider* > : ObjectTypeConverter< ::Phonon::VolumeSlider >
{
};

template<>
struct Converter< ::Phonon::VolumeSlider > : ObjectTypeReferenceConverter< ::Phonon::VolumeSlider >
{
};

template<>
struct Converter< ::Phonon::VideoWidget::AspectRatio > : EnumConverter< ::Phonon::VideoWidget::AspectRatio >
{
};

template<>
struct Converter< ::Phonon::VideoWidget::ScaleMode > : EnumConverter< ::Phonon::VideoWidget::ScaleMode >
{
};

template<>
struct Converter< ::Phonon::VideoWidget* > : ObjectTypeConverter< ::Phonon::VideoWidget >
{
};

template<>
struct Converter< ::Phonon::VideoWidget > : ObjectTypeReferenceConverter< ::Phonon::VideoWidget >
{
};

template<>
struct Converter< ::Phonon::VideoPlayer* > : ObjectTypeConverter< ::Phonon::VideoPlayer >
{
};

template<>
struct Converter< ::Phonon::VideoPlayer > : ObjectTypeReferenceConverter< ::Phonon::VideoPlayer >
{
};

template<>
struct Converter< ::Phonon::SeekSlider* > : ObjectTypeConverter< ::Phonon::SeekSlider >
{
};

template<>
struct Converter< ::Phonon::SeekSlider > : ObjectTypeReferenceConverter< ::Phonon::SeekSlider >
{
};

template<>
struct Converter< ::Phonon::EffectDescriptionModel* > : ObjectTypeConverter< ::Phonon::EffectDescriptionModel >
{
};

template<>
struct Converter< ::Phonon::EffectDescriptionModel > : ObjectTypeReferenceConverter< ::Phonon::EffectDescriptionModel >
{
};

template<>
struct Converter< ::Phonon::AudioOutputDeviceModel* > : ObjectTypeConverter< ::Phonon::AudioOutputDeviceModel >
{
};

template<>
struct Converter< ::Phonon::AudioOutputDeviceModel > : ObjectTypeReferenceConverter< ::Phonon::AudioOutputDeviceModel >
{
};

template<>
struct Converter< ::Phonon::BackendCapabilities::NotifierWrapper* > : ObjectTypeConverter< ::Phonon::BackendCapabilities::NotifierWrapper >
{
};

template<>
struct Converter< ::Phonon::BackendCapabilities::NotifierWrapper > : ObjectTypeReferenceConverter< ::Phonon::BackendCapabilities::NotifierWrapper >
{
};

template<>
struct Converter< ::Phonon::MediaObject* > : ObjectTypeConverter< ::Phonon::MediaObject >
{
};

template<>
struct Converter< ::Phonon::MediaObject > : ObjectTypeReferenceConverter< ::Phonon::MediaObject >
{
};

template<>
struct Converter< ::Phonon::MediaController::Feature > : EnumConverter< ::Phonon::MediaController::Feature >
{
};
template<>
struct Converter< ::QFlags<Phonon::MediaController::Feature> > : QFlagsConverter< ::QFlags<Phonon::MediaController::Feature> >
{
};

template<>
struct Converter< ::Phonon::MediaController* > : ObjectTypeConverter< ::Phonon::MediaController >
{
};

template<>
struct Converter< ::Phonon::MediaController > : ObjectTypeReferenceConverter< ::Phonon::MediaController >
{
};

template<>
struct Converter< ::Phonon::Effect* > : ObjectTypeConverter< ::Phonon::Effect >
{
};

template<>
struct Converter< ::Phonon::Effect > : ObjectTypeReferenceConverter< ::Phonon::Effect >
{
};

template<>
struct Converter< ::Phonon::VolumeFaderEffect::FadeCurve > : EnumConverter< ::Phonon::VolumeFaderEffect::FadeCurve >
{
};

template<>
struct Converter< ::Phonon::VolumeFaderEffect* > : ObjectTypeConverter< ::Phonon::VolumeFaderEffect >
{
};

template<>
struct Converter< ::Phonon::VolumeFaderEffect > : ObjectTypeReferenceConverter< ::Phonon::VolumeFaderEffect >
{
};

template<>
struct Converter< ::Phonon::AbstractMediaStream* > : ObjectTypeConverter< ::Phonon::AbstractMediaStream >
{
};

template<>
struct Converter< ::Phonon::AbstractMediaStream > : ObjectTypeReferenceConverter< ::Phonon::AbstractMediaStream >
{
};

template<>
struct Converter< ::Phonon::AbstractAudioOutput* > : ObjectTypeConverter< ::Phonon::AbstractAudioOutput >
{
};

template<>
struct Converter< ::Phonon::AbstractAudioOutput > : ObjectTypeReferenceConverter< ::Phonon::AbstractAudioOutput >
{
};

template<>
struct Converter< ::Phonon::AudioOutput* > : ObjectTypeConverter< ::Phonon::AudioOutput >
{
};

template<>
struct Converter< ::Phonon::AudioOutput > : ObjectTypeReferenceConverter< ::Phonon::AudioOutput >
{
};

} // namespace Shiboken

// User defined converters --------------------------------------------
// Generated converters implemantations -------------------------------

inline bool Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(PyObject* pyobj)
{
    if (ValueTypeConverter< ::Phonon::MediaSource >::isConvertible(pyobj))
        return true;
    SbkObjectType* shiboType = reinterpret_cast<SbkObjectType*>(SbkType< ::Phonon::MediaSource >());
    return Shiboken::Converter< ::Phonon::AbstractMediaStream * >::checkType(pyobj)
         || Shiboken::Converter< ::Phonon::DiscType >::checkType(pyobj)
         || Shiboken::Converter< ::QIODevice * >::checkType(pyobj)
         || Shiboken::Converter< QString >::checkType(pyobj)
         || Shiboken::Converter< ::QUrl >::checkType(pyobj)
         || (ObjectType::isExternalConvertible(shiboType, pyobj));
}

inline ::Phonon::MediaSource Shiboken::Converter< ::Phonon::MediaSource >::toCpp(PyObject* pyobj)
{
    if (PyObject_TypeCheck(pyobj, SbkType< ::Phonon::MediaSource >()))
        return *Shiboken::Converter< Phonon::MediaSource* >::toCpp(pyobj);
    else if (Shiboken::Converter< ::Phonon::AbstractMediaStream * >::checkType(pyobj))
        return Phonon::MediaSource(Shiboken::Converter< ::Phonon::AbstractMediaStream * >::toCpp(pyobj));
    else if (Shiboken::Converter< ::Phonon::DiscType >::checkType(pyobj))
        return Phonon::MediaSource(Shiboken::Converter< ::Phonon::DiscType >::toCpp(pyobj));
    else if (Shiboken::Converter< ::QIODevice * >::checkType(pyobj))
        return Phonon::MediaSource(Shiboken::Converter< ::QIODevice * >::toCpp(pyobj));
    else if (Shiboken::Converter< QString >::checkType(pyobj))
        return Phonon::MediaSource(Shiboken::Converter< QString >::toCpp(pyobj));
    else if (Shiboken::Converter< ::QUrl >::checkType(pyobj))
        return Phonon::MediaSource(Shiboken::Converter< ::QUrl >::toCpp(pyobj));
    else
        return Shiboken::ValueTypeConverter< ::Phonon::MediaSource >::toCpp(pyobj);
}


#endif // SBK_PHONON_PYTHON_H

